/**
 * Sample React Native App
 * https://github.com/facebook/react-native
 *
 * @format
 * @flow strict-local
 */

 import React, { useEffect } from 'react';
 import moment from 'moment';
 import AsyncStorage from '@react-native-community/async-storage';
 import { StyleSheet, ScrollView, View, Text, StatusBar } from 'react-native';
 import { SafeAreaProvider } from 'react-native-safe-area-context';
 import Router from './router';
 import { configure } from "mobx"
 import { Provider } from 'mobx-react';
 import Store from './src/stores/index';
 import { colors } from './src/assets/styles/colors-theme';
 import { NavigationContainer, useFocusEffect } from '@react-navigation/native';
 import { createStackNavigator, HeaderBackButton } from '@react-navigation/stack';
 import { createMaterialBottomTabNavigator } from '@react-navigation/material-bottom-tabs';
 import { createBottomTabNavigator } from '@react-navigation/bottom-tabs';
 import {
   Header,
   LearnMoreLinks,
   Colors,
   DebugInstructions,
   ReloadInstructions,
 } from 'react-native/Libraries/NewAppScreen';
 import Icon from 'react-native-vector-icons/dist/MaterialCommunityIcons';
 
 Icon.loadFont();
 console.disableYellowBox = true;
 const Stack = createStackNavigator();
 const BottomTab = createBottomTabNavigator();
 
 const App: () => React$Node = () => {
   configure({
     enforceActions: "never",
   })
   return (
     <>
       <Provider {...Store}>
 
         <SafeAreaProvider>
           <StatusBar
             animated={true}
             barStyle={'light-content'}
             backgroundColor={'black'}
             translucent={true}
           />
           <NavigationContainer
             onStateChange={state => Store.appStore.setRouterState(state)}
             ref={navigatorRef => Store.appStore.setRouterRef(navigatorRef)}>
             <Router />
           </NavigationContainer>
         </SafeAreaProvider>
       </Provider>
     </>
   );
 };
 
 const styles = StyleSheet.create({
   scrollView: {
     backgroundColor: Colors.lighter,
   },
   engine: {
     position: 'absolute',
     right: 0,
   },
   body: {
     backgroundColor: colors.bgc,
   },
   sectionContainer: {
     marginTop: 32,
     paddingHorizontal: 24,
   },
   sectionTitle: {
     fontSize: 24,
     fontWeight: '600',
     color: Colors.black,
   },
   sectionDescription: {
     marginTop: 8,
     fontSize: 18,
     fontWeight: '400',
     color: Colors.dark,
   },
   highlight: {
     fontWeight: '700',
   },
   footer: {
     color: Colors.dark,
     fontSize: 12,
     fontWeight: '600',
     padding: 4,
     paddingRight: 12,
     textAlign: 'right',
   },
 });
 
 export default App;
 