import React, { Component } from "react";
import { Image as ReactImage, ScrollView, StyleSheet, Text, View, TouchableOpacity, TextInput, Platform, FlatList, Alert } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import FastImage from 'react-native-fast-image'
var _ = require('lodash');
import Loading from '../../components/Loading';
import TopBar from '../../components/topBar'
import Toast, { DURATION } from 'react-native-easy-toast';
import TitleBar from '../../components/titleBar'
import { width, height } from '../../services/screen'
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import { colors } from '../../assets/styles/colors-theme';
import I18n from '../../services/i18n'
import Menu, {
    MenuProvider,
    MenuTrigger,
    MenuOptions,
    MenuOption,
    renderers,
} from 'react-native-popup-menu';
import moment from "moment";
const { SlideInMenu } = renderers;

const Cart = inject("appStore")(observer(class Cart extends React.Component {

    cartItems = []
    itemQty = []
    coupon = ''
    couponData = null

    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {
            cartItems: observable,
            coupon: observable,
            couponData: observable,
        });
        for (var i = 1; i <= 30; i++) {
            this.itemQty.push(i)
        }
    }

    componentDidMount() {

        this._unsubscribe = this.props.navigation.addListener('focus', () => {
            this.cartItemsHandler()
            this.store.getCoupons()
        });


    }


    async orderAction() {
        if (this.store.logined) {
            var data = {
                items: [],
                coupon: ''
            }
            var orderData = {
                item: _.cloneDeep(this.cartItems),
                couponData: this.store.couponData != null ? this.store.couponData : null,
            }
            Promise.all(
                this.cartItems.map((item, index) => {
                    var itemData = {
                        itemId: item.productId,
                        qty: item.qty,
                        productOptionsId: item.option != null ? item.option.productOptionsId : ''
                    }
                    data.items.push(itemData)
                })

            )
            if (this.store.couponData != null) {
                data.coupon = this.store.couponData.couponId
            }
            console.log(data)
            this.store.order(data, orderData, this)
        } else {
            Alert.alert('', I18n.t('pleaseLogin'), [{ text: 'OK', onPress: () => this.props.navigation.navigate('Login') }],
                { cancelable: false })
        }

        //this.props.navigation.navigate('Shipping', { orderData: data })
    }


    componentWillUnmount() {
        this._unsubscribe();
    }

    async cartItemsHandler() {
        this.cartItems = []
        this.store.shoppingCart.map(async (item, index) => {
            var items = await this.store.products.find(element => element.productId == item.id);
            if (items != undefined) {
                items.qty = item.qty
                if (item.option != null) {
                    var itemsOptionIndex = await items.options.findIndex(e => e.productOptionsId == item.option.productOptionsId)
                    if (itemsOptionIndex > -1) {
                        items.option = items.options[itemsOptionIndex]
                    } else {
                        items.option = null
                    }
                }
                this.cartItems.push(items)
            }
        })
    }

    async submitCouponAction() {
        const couponData = await this.couponsHandler()
        console.info(couponData)
        if (couponData.data != null) {
            this.store.couponData = couponData.data
        } else {
            this.store.coupon = '';
            this.store.couponData = null;
            this.refs.toast.show(couponData.message)
        }
    }

    totalPrice() {
        var total = 0
        Promise.all(this.cartItems.map((item, index) => {
            total += item.price * item.qty
        }))
        if (this.store.couponData != null) {
            if (this.store.couponData.couponType == 'fix') {
                total = total - parseInt(this.store.couponData.couponValue)
            } else {
                total = (total * (100 - parseInt(this.store.couponData.couponValue))) / 100
            }
        }
        return total.toFixed(1)
    }

    async couponsHandler() {
        var couponData = {
            data: null,
            message: '',
        }
        var couponIndex = await this.store.coupons.findIndex(e => e.code == this.store.coupon)
        if (couponIndex > -1) {
            if (this.store.coupons[couponIndex].enable == 1) {
                if (moment(this.store.coupons[couponIndex].startDate, 'YYYY-MM-DD').valueOf() <= moment().valueOf()) {
                    if (moment(this.store.coupons[couponIndex].endDate, 'YYYY-MM-DD').valueOf() > moment().valueOf()) {
                        couponData.data = this.store.coupons[couponIndex]
                        return couponData
                    } else {
                        couponData.message = I18n.t('couponExpirted')
                        return couponData
                    }
                } else {
                    couponData.message = I18n.t('canNotUseYet')
                    return couponData
                }
            } else {
                couponData.message = I18n.t('notExist')
                return couponData
            }
        } else {
            couponData.message = I18n.t('notExist')
            return couponData
        }
    }

    render() {
        const name = I18n.t('shoppingCart');

        return (

            <MenuProvider style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <Loading loading={this.store.loading} />
                <TopBar self={this} />
                <TitleBar title={name} self={this} />

                {this.cartItems.length > 0 ? (<KeyboardAwareScrollView
                    style={{ flex: 1 }}
                    // enableOnAndroid={true}
                    // keyboardShouldPersistTaps={"handled"}
                    enableResetScrollToCoords={false} nestedScrollEnabled={true}>
                    {this.cartItems.map((item, index) => {
                        console.info(item)
                        return (
                            <View style={{ flexDirection: "row", paddingHorizontal: 10, marginBottom: 10 }}>
                                <FastImage
                                    // source={{ uri: item?.images?.[0]?.src }}
                                    source={{ uri: this.store.uriLink + item.image }}
                                    style={{ width: 185, height: 185, resizeMode: "cover", borderColor: colors.BORDER_PINK, borderWidth: 1, borderRadius: 10 }}
                                />
                                <View style={{ padding: 5 }}>
                                    <View style={{}}>
                                        <Text style={styles.home_product80938ed2} numberOfLines={1}>
                                            {item?.name}
                                        </Text>
                                        {/* <Text style={styles.home_product80938ed3}>{item?.color}</Text> */}
                                        {/* <Text style={styles.home_product80938ed3}>{item ?.origin}</Text> */}
                                        <Text style={styles.home_product80938ed2}>${item?.price}</Text>
                                    </View>
                                    {/* <TouchableOpacity style={{ marginTop: 10 }}>
                                        <View
                                            style={{
                                                width: 115,
                                                height: 25,
                                                marginTop: 10,
                                                borderColor: colors.BORDER_PINK,
                                                borderWidth: 1,
                                                borderRadius: 4,
                                                justifyContent: "center",
                                                alignItems: "center",
                                                backgroundColor: "white",
                                            }}
                                        >
                                            <Text style={{ fontSize: 13 }}>Vintage</Text>
                                            <ReactImage
                                                source={images.ICON_ARROW_DOWN_OUTLINE}
                                                style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 5, right: 6 }}
                                            />
                                        </View>
                                    </TouchableOpacity> */}
                                    <Menu
                                        style={{ marginTop: 25 }}
                                        name={"selectQty" + item.productId}
                                        renderer={SlideInMenu}
                                        onSelect={value => {
                                            console.info(value)
                                            this.store.changeQtyOnCart(item.productId, index, value, this);
                                        }}>
                                        <MenuTrigger
                                            style={{
                                                width: 115,
                                                height: 25,
                                                // marginTop: 35,
                                                borderColor: colors.BORDER_PINK,
                                                borderWidth: 1,
                                                borderRadius: 4,
                                                justifyContent: "center",
                                                alignItems: "center",
                                                backgroundColor: "white",
                                            }}
                                        >
                                            <Text style={{ fontSize: 13 }}>{item.qty}</Text>
                                            <ReactImage
                                                source={images.ICON_ARROW_DOWN_OUTLINE}
                                                style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 5, right: 6 }} />

                                        </MenuTrigger>
                                        <MenuOptions
                                            customStyles={{
                                                optionText: {
                                                    margin: 5,
                                                    color: 'black',
                                                    fontSize: 20,
                                                },
                                                optionWrapper: {
                                                    // backgroundColor: colors.MAIN,
                                                    alignItems: 'center',
                                                    backgroundColor: 'white'
                                                },
                                            }}>
                                            <FlatList
                                                data={this.itemQty}
                                                renderItem={({ item }) => (
                                                    <MenuOption value={item} text={item} />
                                                )}
                                                style={{ height: 150, backgroundColor: 'white' }}
                                            />
                                        </MenuOptions>
                                    </Menu>
                                    {
                                        item.option != null ? (<View>
                                            <Menu
                                                style={{ marginTop: 10 }}
                                                name={"selectOption" + item.option.name}
                                                renderer={SlideInMenu}
                                                onSelect={value => {
                                                    console.info(value)

                                                    this.store.changeOptionOnCart(item.productId, index, value, this)
                                                }}>
                                                <MenuTrigger
                                                    style={{
                                                        width: 115,
                                                        height: 25,
                                                        // marginTop: 35,
                                                        borderColor: colors.BORDER_PINK,
                                                        borderWidth: 1,
                                                        borderRadius: 4,
                                                        justifyContent: "center",
                                                        alignItems: "center",
                                                        backgroundColor: "white",
                                                    }}
                                                >
                                                    <Text style={{ fontSize: 13 }}>{item.option.name}</Text>
                                                    <ReactImage
                                                        source={images.ICON_ARROW_DOWN_OUTLINE}
                                                        style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 5, right: 6 }} />

                                                </MenuTrigger>
                                                <MenuOptions
                                                    customStyles={{
                                                        optionText: {
                                                            margin: 5,
                                                            color: 'black',
                                                            fontSize: 20,
                                                        },
                                                        optionWrapper: {
                                                            // backgroundColor: colors.MAIN,
                                                            alignItems: 'center',
                                                            backgroundColor: 'white'
                                                        },
                                                    }}>
                                                    <FlatList
                                                        data={item.options}
                                                        renderItem={(data) => (
                                                            <MenuOption value={data.item} text={data.item.name} />
                                                        )}
                                                        style={{ height: 150, backgroundColor: 'white' }}
                                                    />
                                                </MenuOptions>
                                            </Menu>
                                        </View>) : (<View />)
                                    }

                                    <Text style={{ fontSize: 12, marginTop: 10 }}>{I18n.t("inStock")}</Text>
                                    <TouchableOpacity style={{ marginTop: 10 }}
                                        onPress={() => { this.store.deleteShoppingCart(item.productId, index, this) }}>
                                        <ReactImage source={images.ICON_TRASH_OUTLINE} style={{ width: 20, height: 20, resizeMode: "contain", }} />
                                    </TouchableOpacity>
                                </View>
                            </View>
                        );
                    })}
                    <View style={{ paddingHorizontal: 10, marginTop: 20 }}>
                        <View style={{ flexDirection: "row" }}>
                            <Text style={{ flex: 4, paddingLeft: 15 }}></Text>
                            <Text style={{ flex: 1 }}>{I18n.t("price")}</Text>
                        </View>
                        <View style={{ flex: 1, height: 0, borderTopColor: "black", borderTopWidth: 1, marginVertical: 5 }} />
                        {this.cartItems.map((item, index) => {
                            return (
                                <View style={{ flexDirection: "row", paddingLeft: 10, marginVertical: 10 }}>
                                    <View style={{ flex: 4, flexDirection: "row" }}>
                                        <Text style={{ width: 30 }}>{index + 1}</Text>
                                        <View>
                                            <Text
                                                style={{
                                                    width: width / 2,
                                                    color: "rgba(39, 40, 51, 1)",
                                                    fontSize: 13,
                                                    fontFamily: "Avenir",
                                                }}
                                            >
                                                {item?.name}
                                            </Text>
                                            <Text
                                                style={{
                                                    color: "rgba(39, 40, 51, 1)",
                                                    fontSize: 12,
                                                    fontFamily: "Avenir",
                                                }}
                                            >
                                                {item?.origin}
                                            </Text>

                                        </View>
                                    </View>
                                    <View style={{ flex: 1 }}>
                                        <Text
                                            style={{
                                                color: "rgba(39, 40, 51, 1)",
                                                fontSize: 13,
                                                fontFamily: "Avenir",
                                            }}
                                        >
                                            ${item?.price * item.qty}
                                        </Text>
                                    </View>
                                </View>
                            );
                        })}
                        <View style={{ flex: 1, height: 0, borderTopColor: "black", borderTopWidth: 1, marginVertical: 5 }} />
                        <View style={{ flexDirection: "row" }}>
                            <View style={{ flex: 0.75, flexDirection: 'row', alignItems: 'center', }}>
                                <TextInput
                                    style={styles.inputStyle}
                                    placeholder={I18n.t("cartCoupon")}
                                    value={this.store.coupon}
                                    onChangeText={text => this.store.coupon = text}
                                    returnKeyType={'done'}
                                    onSubmitEditing={() => { this.submitCouponAction() }}
                                />
                                <TouchableOpacity
                                    onPress={() => {
                                        this.submitCouponAction()
                                    }}
                                >
                                    <View
                                        style={{
                                            width: 50,
                                            height: 35,
                                            marginLeft: 10,
                                            borderRadius: 8,
                                            justifyContent: "center",
                                            alignItems: "center",
                                            backgroundColor: colors.BORDER_PINK,
                                        }}
                                    >
                                        <Text style={{ color: "white" }}>{I18n.t('submit')}</Text>
                                    </View>
                                </TouchableOpacity>
                            </View>
                            <View style={{ flex: 0.25, }}>
                                {this.store.couponData != null ? (
                                    <Text>
                                        {'- ' + this.store.couponData.couponValue + (this.store.couponData.couponType == 'fix' ? ' HKD' : ' %')}
                                    </Text>
                                ) : (<View />)}
                                <Text>{I18n.t("totalPrice")}</Text>
                                <Text>{"HK$ " + this.totalPrice()}</Text>
                            </View>
                        </View>
                        <View style={{ flexDirection: "row", marginVertical: 20 }}>
                            <View style={{ flex: 1 }} />
                            <TouchableOpacity
                                onPress={() => {
                                    this.orderAction()
                                    //  this.props.navigateTo({ screen: "shipping" });
                                }}
                            >
                                <View
                                    style={{
                                        width: 140,
                                        height: 30,
                                        marginTop: 10,
                                        borderRadius: 8,
                                        justifyContent: "center",
                                        alignItems: "center",
                                        backgroundColor: colors.BORDER_PINK,
                                    }}
                                >
                                    <Text style={{ color: "white" }}>{I18n.t('proceedToCheckOut')}</Text>
                                </View>
                            </TouchableOpacity>
                        </View>
                    </View>
                </KeyboardAwareScrollView>) : (<View style={{ flex: 1, marginTop: 80, alignItems: 'center' }}>
                    {/* <ReactImage
                        source={images.ICON_HEART}
                        style={{
                            height: 140,
                            resizeMode: "contain",

                        }}
                    /> */}
                    <Text style={{ fontSize: 18, marginTop: 40 }}>{I18n.t("yourShoppingCartIsEmpty")}</Text>
                    {/* <Text style={{ fontSize: 18, marginTop: 5 }}>{"左上返回繼續購物吧！"}</Text> */}
                </View>)}
                <Toast
                    ref="toast"
                    style={{ backgroundColor: colors.BORDER_PINK }}
                    position="center"
                    positionValue={200}
                    fadeInDuration={750}
                    fadeOutDuration={2000}
                    opacity={0.8}
                    textStyle={{ color: 'white' }}
                />

            </MenuProvider>

        );
    }
}))



const styles = StyleSheet.create({
    home_product80938ed2: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 13,
        fontWeight: "bold",
        fontFamily: "Avenir",
        width: width / 2.5
    },
    home_product80938ed3: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 12,
        fontFamily: "Avenir",
    },
    inputStyle: {
        width: 100,
        height: 35,
        borderColor: colors.BORDER_PINK,
        borderWidth: 1,
        borderRadius: 4,
        justifyContent: "center",
        alignItems: "center",
        backgroundColor: "white",
        fontSize: 12,
        // paddingHorizontal: 7,
        // marginBottom: Platform.OS === 'ios' ? 3 : 0,
        paddingVertical: 0,
    }
});



export default Cart
