import React, { Component } from "react";
import { Image, ScrollView, StyleSheet, Text, FlatList, View, TouchableOpacity } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { inject, observer } from "mobx-react"
import { observable, makeObservable, action } from 'mobx'
import TopBar from '../../components/topBar'
import TitleBar from '../../components/titleBar'
import Loading from '../../components/Loading';
import { colors } from '../../assets/styles/colors-theme';
import { images } from "../../assets/images/index";
import FastImage from 'react-native-fast-image'
import I18n from '../../services/i18n'
import { width, height } from '../../services/screen'
import FavouriteButton from '../../components/favouriteButton'
const CategoryGrid = inject("appStore")(observer(class CategoryGrid extends React.Component {
    subCategory = this.props.route.params.subCategory;
    categoryId = this.props.route.params.catId;
    subCategorySelected = ''
    sortSelected = '0'
    cartegoryItems = []
    sortOptions = [
        { name: I18n.t('priceLowToHigh'), id: '0' },
        { name: I18n.t('priceHighToLow'), id: '1' },
        // { name: "熱門", id: '2' },
        // { name: "新到貨品", id: '3' },
        // { name: "折扣", id: '4' },
    ]
    constructor(props) {
        super(props);
        this.store = props.appStore
        this.state = { isCategory: true, firstFilter: "LuLu系列", secondFilter: "熱門" };
        makeObservable(this, {
            subCategory: observable,
            subCategorySelected: observable,
            cartegoryItems: observable,
            sortOptions: observable,
            sortSelected: observable,
            changeSubCategory: action,
        });
        this.subCategory.splice(0, 0, { name: I18n.t("all"), categoryId: 'all', subCategoryId: 'all' });
    }

    componentDidMount() {
        if (this.subCategory.length > 0) {
            this.subCategorySelected = this.subCategory[0].subCategoryId
        }
        this.itemsFilter()
    }

    async itemsFilter() {
        this.cartegoryItems = []
        if (this.subCategorySelected != 'all') {
            this.cartegoryItems = await this.store.products.filter(value => value.subCategoryId == this.subCategorySelected)
        } else {
            this.cartegoryItems = await this.store.products.filter(value => value.categoryId == this.categoryId)
        }
        this.sortItems()
    }

    async sortItems() {
        switch (this.sortSelected) {
            case '0':
                this.cartegoryItems = this.cartegoryItems.sort((a, b) =>
                    parseInt(a.price) > parseInt(b.price) ? 1 : parseInt(b.price) > parseInt(a.price) ? -1 : 0,
                )
                break;
            case '1':
                this.cartegoryItems = this.cartegoryItems.sort((a, b) =>
                    parseInt(a.price) < parseInt(b.price) ? 1 : parseInt(b.price) < parseInt(a.price) ? -1 : 0,

                )
                break;
            case '2':
                //  this.cartegoryItems = await this.cartegoryItems.filter(value => value.subCategoryId == this.subCategorySelected)
                break;
            case '3':
                break;
            case '4':
                break;
        }
    }

    changeSubCategory(id) {
        this.subCategorySelected = id
        this.itemsFilter()
    }
    changeSortOptions(id) {
        this.sortSelected = id
        this.sortItems()
    }


    renderItemsList() {
        return this.cartegoryItems.map((item, index, array) => {
            const newRow = !(index % 2);
            const secondItem = index + 1 < array.length ? array[index + 1] : undefined;

            return (
                <Row key={item.productId} style={{ paddingHorizontal: 10 }}>
                    {!!newRow ? (
                        <>
                            {this._renderCol(item)}
                            {this._renderCol(secondItem)}
                        </>
                    ) : null}
                </Row>
            );
        })
    }


    _renderCol(item) {
        const imageSrc = item ?.image;
        const name = item ?.name;

        return (
            <Col>
                {!!item && (
                    <TouchableOpacity
                        style={{
                            flex: 1,
                            paddingHorizontal: 10,
                        }}
                        onPress={() => {
                            this.store.goToProductDetails(item.productId, this);
                        }}
                    >
                        <FastImage
                            source={{ uri: this.store.uriLink + item.image }}
                            style={{
                                borderRadius: 10,
                                width: undefined,
                                height: 160,
                                resizeMode: "cover",
                                marginVertical: 10,
                                borderColor: colors.BORDER_PINK,
                                borderWidth: 1,
                            }}
                        />
                        <View
                            style={{
                                flex: 1,
                                justifyContent: "center",
                                // alignItems: "center",
                            }}
                        >
                            <Text style={styles.home_product80938ed2} numberOfLines={1}>
                                {name}
                            </Text>
                            <View style={{ flexDirection: 'row', alignItems: 'center' }}>
                                <Text style={styles.home_product80938ed2}>${item.price}</Text>
                                {/* <FavouriteButton data={item} /> */}
                            </View>
                        </View>
                    </TouchableOpacity>
                )}
            </Col>
        );
    }

    renderSubCategory = ({ item, index, separators }) => {
        return (
            <TouchableOpacity
                style={{ height: 60 }}
                onPress={() => {
                    this.changeSubCategory(item.subCategoryId)
                }}
            >
                <View
                    style={{

                        // width: 75,
                        alignItems: "center",
                        borderBottomColor: colors.BORDER_PINK,
                        borderBottomWidth: this.subCategorySelected == item.subCategoryId ? 4 : 0,
                    }}
                >
                    <Text
                        style={{
                            marginTop: 10,
                            marginBottom: 5,
                            fontSize: 14,
                            fontFamily: "Avenir",
                            textAlign: "center",
                            fontWeight: "bold",
                        }}
                        numberOfLines={2}
                    >
                        {item ?.name}
                    </Text>
                </View>
            </TouchableOpacity>
        );
    }

    render() {


        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN, }}>
                <Loading loading={this.store.loading} />
                <TopBar self={this} />
                <TitleBar title={this.props.route.params.name} self={this} />
                {this.subCategory.length > 0 ? (<View style={{ height: 40 }}>
                    <FlatList
                        style={{

                            width: width,
                        }}
                        data={
                            this.subCategory
                        }
                        horizontal={true}
                        keyExtractor={(item) => item ?.name.toString()}
                        extraData={this.subCategorySelected}
                        // onEndReachedThreshold={0.01}
                        // onEndReached={(info) => {
                        //   this.pageNum++;
                        //   this.getServerData(this.props, false);
                        // }}
                        ListHeaderComponent={() => {
                            return <View style={{ width: 18, }} />;
                        }}
                        renderItem={this.renderSubCategory}
                        ItemSeparatorComponent={() => {
                            return <View style={{ width: 15, }} />;
                        }}

                    />
                </View>) : (<View />)}

                <View style={{ flexDirection: "row", height: 40, marginTop: 10 }}>
                    <Text
                        style={{
                            marginTop: 10,
                            fontSize: 14,
                            fontFamily: "Avenir",
                            textAlign: "center",
                            marginLeft: 20,
                            fontWeight: "bold",
                        }}
                    >
                        {I18n.t('arrange')}
                    </Text>
                    <FlatList
                        style={{

                        }}
                        data={
                            this.sortOptions
                        }
                        horizontal={true}
                        keyExtractor={(item) => item ?.name.toString()}
                        extraData={this.sortSelected}
                        // onEndReachedThreshold={0.01}
                        // onEndReached={(info) => {
                        //   this.pageNum++;
                        //   this.getServerData(this.props, false);
                        // }}
                        ListHeaderComponent={() => {
                            return <View style={{ width: 15, }} />;
                        }}
                        renderItem={({ item, index, separators }) => {
                            const { secondFilter } = this.state;
                            return (
                                <TouchableOpacity
                                    style={{ flex: 1 }}
                                    onPress={() => {
                                        // this.props.navigateTo({ screen: "productDetails", payload: { product: item } });
                                        this.changeSortOptions(item.id)
                                    }}
                                >
                                    <View
                                        style={{

                                            alignItems: "center",
                                            borderBottomColor: colors.BORDER_PINK,
                                            borderBottomWidth: this.sortSelected === item ?.id ? 3 : 0,
                                        }}
                                    >
                                        <Text
                                            style={{
                                                marginTop: 10,
                                                fontSize: 14,
                                                fontFamily: "Avenir",
                                                textAlign: "center",
                                            }}
                                            numberOfLines={2}
                                        >
                                            {item ?.name}
                                        </Text>
                                    </View>
                                </TouchableOpacity>
                            );
                        }}
                        ItemSeparatorComponent={() => {
                            return <View style={{ width: 15, }} />;
                        }}
                        ListFooterComponent={() => {
                            return <View style={{ width: 18, }} />;
                        }}
                    />
                </View>
                <ScrollView
                    style={{
                        marginTop: 10,
                    }}
                >
                    <Grid
                        style={{
                            width: "100%",
                            paddingBottom: 20,
                        }}
                    >
                        {
                            this.renderItemsList()
                        }
                    </Grid>
                </ScrollView>
            </View>
        );
    }
}))



const styles = StyleSheet.create({
    homeFirstTimeLoginIn2: {
        opacity: 1,
        backgroundColor: "rgba(0, 0, 0, 1)",
        flex: 1,
    },
    homeFirstTimeLoginIn2_rectangle66fb9092: {
        opacity: 1,
        backgroundColor: "rgba(255, 255, 255, 1)",
        borderTopLeftRadius: 20,
        borderTopRightRadius: 20,
        borderBottomLeftRadius: 0,
        borderBottomRightRadius: 0,
        width: width,
        height: 810,
        marginTop: 110,
    },
    homeFirstTimeLoginIn2_storetopnavgwhite: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "transparent",
        width: width,
        height: 80,
        left: 0,
        top: 0,
    },
    homeFirstTimeLoginIn2_storetopnavgwhite_frame: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(0, 0, 0, 1)",
        borderTopLeftRadius: 0,
        borderTopRightRadius: 0,
        borderBottomLeftRadius: 0,
        borderBottomRightRadius: 0,
        width: width,
        height: 79,
    },
    homeFirstTimeLoginIn2_storetopnavgwhite_dashboard: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(255, 255, 255, 1)",
        fontSize: 20,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",
        width: width,
        height: 36,
        top: 51.5,
    },
    homeFirstTimeLoginIn2_storetopnavgwhite_shaped509bf30: {
        opacity: 1,
        position: "absolute",
        width: 18,
        height: 16,
        left: 30,
        top: 60,
    },
    homeFirstTimeLoginIn2_storetopnavgwhite_combinedShape: {
        opacity: 1,
        position: "absolute",
        padding: 5,
        width: 28,
        height: 28,
        right: 30,
        top: 54,
    },
    homeFirstTimeLoginIn2_iconsfilter: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "transparent",
        width: 24,
        height: 24,
        right: 70,
        top: 56,
    },
    homeFirstTimeLoginIn2_iconsfilter_rectangle5: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "transparent",
        borderTopLeftRadius: 0,
        borderTopRightRadius: 0,
        borderBottomLeftRadius: 0,
        borderBottomRightRadius: 0,
        width: 24,
        height: 24,
        left: 0,
        top: 0,
    },
    homeFirstTimeLoginIn2_iconsfilter_symbolsda28c61d: {
        opacity: 1,
        position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        width: 14.06,
        height: 13.48,
        left: 5,
        top: 6,
    },
    homeFirstTimeLoginIn2_iconsfilter_symbolsda28c61d_iconsiconFilterSmall: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 14.06,
        height: 13.48,
        left: 0,
        top: 0,
    },
    homeFirstTimeLoginIn2_iconsfilter_symbolsda28c61d_iconsiconFilterSmall_vector: {
        opacity: 1,
        position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 14.06,
        height: 13.48,
        left: 0,
        top: 0,
    },
    homeFirstTimeLoginIn2_price7b74322a: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 58,
        height: 29,
        left: 64.5,
        top: 337.5,
    },
    homeFirstTimeLoginIn2_pricea89195d3: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 58,
        height: 29,
        left: 64.5,
        top: 562.5,
    },
    homeFirstTimeLoginIn2_pricebb266e6c: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 58,
        height: 29,
        left: 64.5,
        top: 787.5,
    },
    homeFirstTimeLoginIn2_product36fe083a: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 118,
        height: 25,
        left: 34.5,
        top: 309.5,
    },
    homeFirstTimeLoginIn2_product495d9bae: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 142,
        height: 25,
        left: 22.5,
        top: 534.5,
    },
    homeFirstTimeLoginIn2_product847d7843: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 104,
        height: 25,
        left: 41.5,
        top: 759.5,
    },
    homeFirstTimeLoginIn2_pricee74e76d6: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 58,
        height: 29,
        left: 239.5,
        top: 337.5,
    },
    homeFirstTimeLoginIn2_pricee4e6efc9: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 58,
        height: 29,
        left: 239.5,
        top: 562.5,
    },
    homeFirstTimeLoginIn2_price: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        width: 58,
        height: 29,
        left: 239.5,
        top: 787.5,
    },
    homeFirstTimeLoginIn2_product9bcf8c78: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",
    },
    homeFirstTimeLoginIn2_producte240a17f: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",
        width: 42,
        height: 25,
        left: 247.5,
        top: 534.5,
    },
    homeFirstTimeLoginIn2_product: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",
        width: 72,
        height: 25,
        left: 232.5,
        top: 759.5,
    },
    homeFirstTimeLoginIn2_x49785b12082b6ed6c0903aafd7f2f819: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        borderBottomLeftRadius: 6,
        borderBottomRightRadius: 6,
        width: 142,
        height: 141,
        // left: 27,
        // top: 153,
    },
    homeFirstTimeLoginIn2_b47959de1584f16202e18d4d019d8d92: {
        opacity: 1,
        position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        borderBottomLeftRadius: 6,
        borderBottomRightRadius: 6,
        width: 142,
        height: 141,
        left: 27,
        top: 378,
    },
    homeFirstTimeLoginIn2_x18682fbde453e9123c03c20a30d0d353: {
        opacity: 1,
        position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        borderBottomLeftRadius: 6,
        borderBottomRightRadius: 6,
        width: 142,
        height: 141,
        left: 27,
        top: 603,
    },
    homeFirstTimeLoginIn2_x78cdc02e227f9276c86131dcd782f438: {
        opacity: 1,
        position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        borderBottomLeftRadius: 6,
        borderBottomRightRadius: 6,
        width: 142,
        height: 141,
        left: 201,
        top: 153,
    },
    homeFirstTimeLoginIn2_c6a0a6c301d6c8ae63949c6e6d16e48d: {
        opacity: 1,
        position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        borderBottomLeftRadius: 6,
        borderBottomRightRadius: 6,
        width: 142,
        height: 141,
        left: 201,
        top: 378,
    },
    homeFirstTimeLoginIn2_ac8eddaa62b0e5f4a49aa0e16a727fdb: {
        opacity: 1,
        position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        borderBottomLeftRadius: 6,
        borderBottomRightRadius: 6,
        width: 142,
        height: 141,
        left: 201,
        top: 603,
    },

    home_bottomNavigation: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: width,
        height: 66,
        left: 0,
        bottom: 0,
    },
    home_bottomNavigation_rectangle731ec954: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 1)",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        borderTopWidth: 1,
        borderTopColor: "rgba(0, 0, 0, 0)",
        borderRightWidth: 1,
        borderRightColor: "rgba(0, 0, 0, 0)",
        borderBottomWidth: 1,
        borderBottomColor: "rgba(0, 0, 0, 0)",
        borderLeftWidth: 1,
        borderLeftColor: "rgba(0, 0, 0, 0)",
        borderTopLeftRadius: 0,
        borderTopRightRadius: 0,
        borderBottomLeftRadius: 0,
        borderBottomRightRadius: 0,
        width: width,
        height: "100%",
        // left: -0.5,
        // top: -0.5,
    },
    home_bottomNavigation_rectangleCopy3: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "rgba(247, 247, 247, 1)",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        borderTopWidth: 1,
        borderTopColor: "rgba(0, 0, 0, 0)",
        borderRightWidth: 1,
        borderRightColor: "rgba(0, 0, 0, 0)",
        borderBottomWidth: 1,
        borderBottomColor: "rgba(0, 0, 0, 0)",
        borderLeftWidth: 1,
        borderLeftColor: "rgba(0, 0, 0, 0)",
        borderTopLeftRadius: 0,
        borderTopRightRadius: 0,
        borderBottomLeftRadius: 0,
        borderBottomRightRadius: 0,
        width: width,
        height: 0,
        // left: -0.5,
        // top: -0.5,
    },
    home_bottomNavigation_iconsiconHome: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
    },
    home_bottomNavigation_iconsiconHome_iconHome: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 20,
        height: 20,
        left: 0,
        top: 0,
    },
    home_bottomNavigation_symbols: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
    },
    home_bottomNavigation_symbols_iconsiconCategories: {
        opacity: 1,
        position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 20,
        height: 20,
        left: 0,
        top: 0,
    },
    home_bottomNavigation_symbols_iconsiconCategories_iconCategories: {
        opacity: 1,
        position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 20,
        height: 20,
        left: 0,
        top: 0,
    },
    home_bottomNavigation_iconsiconShoppingBag: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
    },
    home_bottomNavigation_iconsiconShoppingBag_iconShoppingBag: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 16,
        height: 20,
        left: 0,
        top: 0,
    },
    home_bottomNavigation_iconsiconBookmark: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
    },
    home_bottomNavigation_iconsiconBookmark_iconBookmark: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 14,
        height: 20,
        left: 0,
        top: 0,
    },
    home_bottomNavigation_iconsiconSettings: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        flex: 1,
        justifyContent: "center",
        alignItems: "center",
    },
    home_bottomNavigation_iconsiconSettings_iconSettings: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 20,
        height: 20,
        left: 0,
        top: 0,
    },
    homeFirstTimeLoginIn1_group2501_producteb7f0ae0: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",
        height: 26,
    },
    home_product80938ed2: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 13,
        fontWeight: "bold",
        fontFamily: "Avenir",
    },
    home_product80938ed3: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 12,
        fontFamily: "Avenir",
    },
});



export default CategoryGrid