import React, { Component } from "react";
import { Image as ReactImage, ScrollView, Text, View, TouchableOpacity, TextInput, Platform } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import FastImage from 'react-native-fast-image'
import TopBar from '../../components/topBar'
import Toast, { DURATION } from 'react-native-easy-toast';
import TitleBar from '../../components/titleBar'
var _ = require('lodash');
import Loading from '../../components/Loading';
import { width, height } from '../../services/screen'
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import { colors } from '../../assets/styles/colors-theme';
import { getStatusBarHeight } from 'react-native-status-bar-height';
import I18n from '../../services/i18n'
import Icon from 'react-native-vector-icons/dist/AntDesign';
import GoogleIcon from 'react-native-vector-icons/dist/MaterialCommunityIcons'
import Menu, {
    MenuProvider,
    MenuTrigger,
    MenuOptions,
    MenuOption,
    renderers,
} from 'react-native-popup-menu';
import moment from "moment";
const { SlideInMenu } = renderers;
import CheckBox from "@react-native-community/checkbox";

const History = inject("appStore")(observer(class History extends React.Component {
    data = this.props.route.params.data
    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {

        });
    }

    confirmAction() {
        const paymentMethod = this.props.route.params.paymentType
        switch (paymentMethod) {
            case 0:
                // return I18n.t('payme_alipay_wechat')
                this.store.payByOther(this);
                break;
            case 1:
                // return I18n.t('payCashAtStore')
                this.store.payByCash(this);
                break;
            case 2:
                //  return I18n.t('creditCardPayment')
                this.store.payByStripe(this);
                break;
            case 3:
                //  return I18n.t('payPalPayment')
                this.store.payByPalPal(this);
                break;

        }
    }

    totalPrice() {
        const items = this.data.items

        var total = 0
        Promise.all(items.map((item, index) => {
            total += item.price * item.qty
        }))
        if (this.data.info.couponId != null) {
            const couponIndex = this.store.coupons.findIndex(e => e.couponId == this.data.info.couponId)
            if (couponIndex > -1) {
                if (this.store.coupons[couponIndex].couponType == 'fix') {
                    total = total - parseInt(this.store.coupons[couponIndex].couponValue)
                } else {
                    total = (total * (100 - parseInt(this.store.coupons[couponIndex].couponValue))) / 100
                }
            }
        }

        return total.toFixed(1)
    }

    shippingTextHandler() {
        const shippingMethod = this.data.info.deliveryLocation

        if (shippingMethod == 1) {
            return I18n.t('pickUpAtTheStore')
        } else {
            return I18n.t('sfShipping')
        }
    }

    paymentTextHandler() {
        const paymentMethod = this.data.info.paymentMethod
        switch (paymentMethod) {
            case 'Other':
                return I18n.t('payme_alipay_wechat')
                break;
            case "Cash":
                return I18n.t('payCashAtStore')
                break;
            case "Stripe":
                return I18n.t('creditCardPayment')
                break;
            case "PayPal":
                return I18n.t('payPalPayment')
                break;
            default:
                return this.data.info.paymentMethod
                break

        }
    }


    render() {

        // const product = this.props.navigator.payloadForScreen?.[this.getScreenName()]?.product;

        const name = I18n.t('orderHistoryTitle');




        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <Loading loading={this.store.loading} />

                <TopBar self={this} />
                <TitleBar title={name} self={this} />

                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>

                    <View style={{ marginHorizontal: 20, marginTop: 10 }}>
                        <View style={{ paddingHorizontal: 0, marginTop: 5 }}>
                            <View style={{ flexDirection: "row" }}>
                                <Text style={{ flex: 4, paddingLeft: 15 }}>{''}</Text>
                                <Text style={{ flex: 1 }}>{I18n.t('price')}</Text>
                            </View>
                            <View style={{ flex: 1, height: 0, borderTopColor: "black", borderTopWidth: 1, marginVertical: 5 }} />
                            {this.data.items.map((item, index) => {
                                return (
                                    <View style={{ flexDirection: "row", paddingLeft: 10, marginVertical: 10 }}>
                                        <View style={{ flex: 4, flexDirection: "row" }}>
                                            <Text style={{ width: 15 }}>{index + 1}</Text>
                                            {/* <FastImage
                                                // source={{ uri: item?.images?.[0]?.src }}
                                                source={{ uri: this.store.uriLink + item.image }}
                                                style={{
                                                    width: 60,
                                                    height: 60,
                                                    marginRight: 5,
                                                    resizeMode: "cover",
                                                    borderColor: colors.BORDER_PINK,
                                                    borderWidth: 1,
                                                    borderRadius: 10,
                                                }}
                                            /> */}
                                            <View style={{ flex: 1 }}>
                                                <Text
                                                    style={{
                                                        color: "rgba(39, 40, 51, 1)",
                                                        fontSize: 13,
                                                        fontFamily: "Avenir",
                                                    }}
                                                >
                                                    {this.store.lang == 'Tc' ? item.productNameTc : item.productNameEn}
                                                </Text>
                                                {item.optionsTc != null ? (<View>
                                                    <Text
                                                        style={{
                                                            color: "rgba(39, 40, 51, 1)",
                                                            fontSize: 13,
                                                            fontFamily: "Avenir",
                                                        }}
                                                    >
                                                        {this.store.lang === 'Tc' ? item.optionsTc : item.optionsEn}
                                                    </Text>
                                                </View>) : (<View />)}
                                            </View>
                                        </View>
                                        <View style={{ flex: 1 }}>
                                            <Text
                                                style={{
                                                    color: "rgba(39, 40, 51, 1)",
                                                    fontSize: 13,
                                                    fontFamily: "Avenir",
                                                }}
                                            >
                                                ${parseFloat(item.price) * parseFloat(item.qty)}
                                            </Text>
                                        </View>
                                    </View>
                                );
                            })}
                            <View style={{ flex: 1, height: 0, borderTopColor: "black", borderTopWidth: 1, marginVertical: 5 }} />
                            <View style={{ flexDirection: "row" }}>
                                <View style={{ flex: 0.75 }} />
                                <View style={{ flex: 0.25 }}>
                                    {this.data.info.couponId != null ? (
                                        <Text>
                                            {'- ' + this.store.coupons[this.store.coupons.findIndex(e => e.couponId == this.data.info.couponId)].couponValue + (this.store.coupons[this.store.coupons.findIndex(e => e.couponId == this.data.info.couponId)].couponType == 'fix' ? ' HKD' : ' %')}
                                        </Text>
                                    ) : (<View />)}
                                    <Text>{I18n.t("totalPrice")}</Text>
                                    <Text>{"HK$ " + this.totalPrice()}</Text>
                                </View>
                            </View>
                            <Text style={{ marginTop: 10 }}>{I18n.t('info')}</Text>
                            <Text style={{ marginTop: 5 }}>{I18n.t('cartRecipientName') + ": " + this.data.info.contactPerson}</Text>
                            <Text>{I18n.t('settingsPhoneNumber') + ": " + this.data.info.contactNumber}</Text>
                            <Text>{I18n.t('loginEmail') + ": " + this.data.info.contactEmail}</Text>
                            <Text style={{ marginTop: 20 }}>{I18n.t('shippingMethods')}</Text>
                            <Text style={{ marginTop: 5 }}>{this.shippingTextHandler()}</Text>
                            <Text>{I18n.t('cartAddress') + ": " + this.data.info.deliveryAddress}</Text>
                            <Text style={{ marginTop: 20 }}>{I18n.t('orderDetailsPaymentMethod')}</Text>
                            <Text style={{ marginTop: 5 }}>{this.paymentTextHandler()}</Text>
                        </View>

                    </View>
                </ScrollView>
            </View>
        );
    }
}))

export default History