import React, { Component } from "react";
import { Image as ReactImage, ScrollView, Text, View, TouchableOpacity, StyleSheet, TextInput,Linking } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import Toast, { DURATION } from 'react-native-easy-toast';
import { observable, makeObservable } from 'mobx'
import moment from 'moment'
import TopBar from '../../components/topBar'
import { colors } from '../../assets/styles/colors-theme';
import I18n from '../../services/i18n'
import TitleBar from '../../components/titleBar'
var _ = require('lodash');
const HistoryList = inject("appStore")(observer(class HistoryList extends React.Component {
    getScreenName() {
        return "profile";
    }
    history = []
    constructor(props) {
        super(props);
        this.store = props.appStore;
        makeObservable(this, {
            history: observable
        });

    }

 
    async componentDidMount() {
        await this.store.getHistory()
        this.history = _.cloneDeep(this.store.history)
        //"2021-12-01 22:10:03"
        this.history = this.history.sort((a, b) =>
            parseInt(moment(b.info.checkoutDate, 'YYYY-MM-DD hh:mm:ss').valueOf()) > parseInt(moment(a.info.checkoutDate, 'YYYY-MM-DD hh:mm:ss').valueOf()) ? 1 : parseInt(moment(a.info.checkoutDate, 'YYYY-MM-DD hh:mm:ss').valueOf()) > parseInt(moment(b.info.checkoutDate, 'YYYY-MM-DD hh:mm:ss').valueOf()) ? -1 : 0,
        )
        console.info(this.history)
    }

    totalPrice(data) {
        var total = 0
        Promise.all(data.items.map((item, index) => {
            total += parseFloat(item.price) * parseFloat(item.qty)
        }))
        if (data.info.couponId != null) {
            const couponIndex = this.store.coupons.findIndex(e => e.couponId == data.info.couponId)
            if (couponIndex > -1) {
                if (this.store.coupons[couponIndex].couponType == 'fix') {
                    total = total - parseInt(this.store.coupons[couponIndex].couponValue)
                } else {
                    total = (total * (100 - parseInt(this.store.coupons[couponIndex].couponValue))) / 100
                }
            }

        }
        return 'HKD ' + total.toFixed(1)
    }

    renderHistoryList() {
        return this.history.map((item, index) => {
            return (
                <TouchableOpacity style={{ flex: 1, marginVertical: 30, marginHorizontal: 10, flexDirection: 'row' }}
                    onPress={() => this.props.navigation.navigate('History', { data: item })}>
                    <View style={{ flex: 0.1 }}>
                        <Text>
                            {index + 1}
                        </Text>
                    </View>
                    <View style={{ flex: 0.4 }}>
                        <Text>
                            {item.info.checkoutDate}
                        </Text>
                    </View>
                    <View style={{ flex: 0.25 }}>
                        <Text>
                            {this.totalPrice(item)}
                        </Text>
                    </View>
                    <View style={{ flex: 0.25 }}>
                        <Text>
                            {item.info.status}
                        </Text>
                    </View>
                </TouchableOpacity>
            )
        })
    }

    render() {


        // const product = this.props.navigator.payloadForScreen?.[this.getScreenName()]?.product;

        const name = I18n.t('orderRecord');

        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <TopBar self={this} />
                <TitleBar title={name} self={this} />
                <View style={{ marginVertical: 10, marginHorizontal: 10, flexDirection: 'row' }}>
                    <View style={{ flex: 0.1 }}>

                    </View>
                    <View style={{ flex: 0.4 }}>
                        <Text style={{ color: colors.BORDER_PINK }}>
                            {I18n.t('orderDetailsOrderDate') + ': '}
                        </Text>
                    </View>
                    <View style={{ flex: 0.25 }}>
                        <Text style={{ color: colors.BORDER_PINK }}>
                            {I18n.t('totalPrice') + ': '}
                        </Text>
                    </View>
                    <View style={{ flex: 0.25 }}>
                        <Text style={{ color: colors.BORDER_PINK }}>
                            {I18n.t('orderStatusTitle') + ': '}
                        </Text>
                    </View>
                </View>
                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>

                    {this.renderHistoryList()}

                </ScrollView>
                <Toast
                    ref="toast"
                    style={{ backgroundColor: colors.BORDER_PINK }}
                    position="center"
                    positionValue={200}
                    fadeInDuration={750}
                    fadeOutDuration={2000}
                    opacity={0.8}
                    textStyle={{ color: 'white' }}
                />
            </View>
        );
    }
}))


export default HistoryList
