import React, { Component } from "react";
import { Image, ScrollView, Text, View, TouchableOpacity, TextInput, Keyboard, TouchableWithoutFeedback, Platform } from "react-native";
import CheckBox from "@react-native-community/checkbox";
import { inject, observer } from "mobx-react"
import Loading from '../../components/Loading';
import { observable, makeObservable } from 'mobx'
import Toast, { DURATION } from 'react-native-easy-toast';
import { colors } from '../../assets/styles/colors-theme';
import { width, height } from '../../services/screen'
import TopBar from '../../components/topBar'
import { images } from "../../assets/images/index";
import I18n from '../../services/i18n'
import TitleBar from '../../components/titleBar'


const ForgotPassword = inject("appStore")(observer(class ForgotPassword extends React.Component {

    email = ''
    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {
            email: observable
        });
    }

    forgotPasswordAction() {
        if (this.email !== '') {
            this.store.forgotPassword(this.email, this)
        } else {
            this.refs.toast.show(I18n.t('pleaseInputYourEmail'));
        }
    }



    render() {

        // const product = this.props.navigator.payloadForScreen?.[this.getScreenName()]?.product;

        const name = I18n.t('forgotPasswordTitle');


        return (
            <TouchableWithoutFeedback onPress={Keyboard.dismiss} accessible={false}>
                <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                    <Loading loading={this.store.loading} />
                    <TopBar self={this} />
                    <TitleBar title={name} self={this} />
                    <View style={{ marginHorizontal: 40, marginTop: 50, justifyContent: 'center', }}>

                        <View style={{ marginTop: 10 }}>
                            <TextInput
                                style={{
                                    width: "100%",
                                    height: 35,
                                    marginTop: 5,
                                    borderColor: colors.BORDER_PINK,
                                    borderWidth: 1,
                                    borderRadius: 4,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: "white",
                                    fontSize: 12,
                                    marginBottom: Platform.OS === 'ios' ? 3 : 0,
                                    paddingVertical: 0,
                                    paddingHorizontal: 7,
                                }}
                                value={this.email}
                                onChangeText={text => this.email = text}
                                placeholder={I18n.t('registrationEmail')}
                            />
                        </View>


                        <TouchableOpacity
                            onPress={() => {
                                // this.store.logined = true
                                // this.props.navigation.goBack()
                                this.forgotPasswordAction()
                            }}
                        >
                            <View
                                style={{
                                    width: "100%",
                                    height: 40,
                                    marginVertical: 30,
                                    borderRadius: 8,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: colors.BORDER_PINK,
                                }}
                            >
                                <Text style={{ color: "white" }}>{I18n.t('forgotPasswordTitle')}</Text>
                            </View>
                        </TouchableOpacity>

                    </View>
                    <Toast
                        ref="toast"
                        style={{ backgroundColor: colors.BORDER_PINK }}
                        position="center"
                        positionValue={200}
                        fadeInDuration={750}
                        fadeOutDuration={2000}
                        opacity={0.8}
                        textStyle={{ color: 'white' }}
                    />
                </View>

            </TouchableWithoutFeedback>
        );
    }
}))


export default ForgotPassword
