import React, { Component } from "react";
import { Image, ScrollView, Text, View, TouchableOpacity, TextInput, Keyboard, TouchableWithoutFeedback, Platform } from "react-native";
import CheckBox from "@react-native-community/checkbox";
import { inject, observer } from "mobx-react"
import Loading from '../../components/Loading';
import { observable, makeObservable } from 'mobx'
import Toast, { DURATION } from 'react-native-easy-toast';
import { colors } from '../../assets/styles/colors-theme';
import { width, height } from '../../services/screen'
import TopBar from '../../components/topBar'
import { images } from "../../assets/images/index";
import I18n from '../../services/i18n'
import TitleBar from '../../components/titleBar'


const Login = inject("appStore")(observer(class Login extends React.Component {

    data = {
        email: '',
        password: '',
    }

    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {
            data: observable
        });
    }

    loginAction() {
        if (this.data.email !== '') {
            if (this.data.password !== '') {
                this.store.loginPost(this.data, this);
            } else {
                this.refs.toast.show(I18n.t('pleaseInputYourPassword'));
            }
        } else {
            this.refs.toast.show(I18n.t('pleaseInputYourEmail'));
        }
    }



    render() {

        // const product = this.props.navigator.payloadForScreen?.[this.getScreenName()]?.product;

        const name = I18n.t('myAccount');


        return (
            <TouchableWithoutFeedback onPress={Keyboard.dismiss} accessible={false}>
                <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                    <Loading loading={this.store.loading} />
                    <TopBar self={this} />
                    <TitleBar title={name} self={this} />
                    <View style={{ marginHorizontal: 40, marginTop: 50, justifyContent: 'center', }}>
                        <Text style={{ fontSize: 16 }}>{I18n.t("loginLogin")}</Text>
                        <View style={{ marginTop: 10 }}>
                            <TextInput
                                style={{
                                    width: "100%",
                                    height: 35,
                                    marginTop: 5,
                                    borderColor: colors.BORDER_PINK,
                                    borderWidth: 1,
                                    borderRadius: 4,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: "white",
                                    fontSize: 12,
                                    marginBottom: Platform.OS === 'ios' ? 3 : 0,
                                    paddingVertical: 0,
                                    paddingHorizontal: 7,
                                }}
                                value={this.data.email}
                                onChangeText={text => this.data.email = text}
                                placeholder={I18n.t('registrationEmail')}
                            />
                        </View>
                        <View style={{ marginTop: 10 }}>
                            <TextInput
                                style={{
                                    width: "100%",
                                    height: 35,
                                    marginTop: 5,
                                    borderColor: colors.BORDER_PINK,
                                    borderWidth: 1,
                                    borderRadius: 4,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: "white",
                                    fontSize: 12,
                                    paddingHorizontal: 7,
                                    marginBottom: Platform.OS === 'ios' ? 3 : 0,
                                    paddingVertical: 0,
                                }}
                                secureTextEntry={true}
                                placeholder={I18n.t("registrationPassword")}
                                value={this.data.password}
                                onChangeText={text => this.data.password = text}
                            />
                        </View>
                        <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 10 }}>
                            <View style={{ flex: 1 }} />
                            <TouchableOpacity
                                onPress={() => {
                                    this.props.navigation.navigate('Signup')
                                }}
                            >
                                <Text style={{ fontSize: 13 }}>{I18n.t("signUp")}</Text>
                            </TouchableOpacity>
                            <Text style={{ marginHorizontal: 10 }}>/</Text>
                            <TouchableOpacity onPress={() => this.props.navigation.navigate('ForgotPassword')}>
                                <Text style={{ fontSize: 13 }}>{I18n.t('loginForgotPassword')}</Text>
                            </TouchableOpacity>
                        </View>
                        <TouchableOpacity
                            onPress={() => {
                                // this.store.logined = true
                                // this.props.navigation.goBack()
                                this.loginAction()
                                // this.props.navigation.navigate('Test')
                            }}
                        >
                            <View
                                style={{
                                    width: "100%",
                                    height: 40,
                                    marginVertical: 30,
                                    borderRadius: 8,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: colors.BORDER_PINK,
                                }}
                            >
                                <Text style={{ color: "white" }}>{I18n.t('loginLogin')}</Text>
                            </View>
                        </TouchableOpacity>

                        <TouchableOpacity onPress={() => this.props.navigation.navigate('Signup')}>
                            <Text style={{ fontSize: 13, color: colors.BORDER_PINK }}>{I18n.t('loginNoAccount') + " " + I18n.t("signUp")}</Text>
                        </TouchableOpacity>
                        {/* <View style={{ flex: 1, borderTopColor: "black", borderTopWidth: 1, marginBottom: 20 }} />
                        <View style={{ justifyContent: "center", alignItems: "center" }}>
                            <Text>OR</Text>
                            <Text style={{ marginTop: 10 }}>以其他帳號登入</Text>
                            <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 20 }}>
                                <Image source={images.ICON_GOOGLE} style={{ width: 55, height: 50, resizeMode: "contain" }} />
                                <Text style={{ marginHorizontal: 40 }}>OR</Text>
                                <Image source={images.ICON_FACEBOOK_LOGIN} style={{ width: 50, height: 50, resizeMode: "contain" }} />
                            </View>
                        </View> */}
                    </View>
                    <Toast
                        ref="toast"
                        style={{ backgroundColor: colors.BORDER_PINK }}
                        position="center"
                        positionValue={200}
                        fadeInDuration={750}
                        fadeOutDuration={2000}
                        opacity={0.8}
                        textStyle={{ color: 'white' }}
                    />
                </View>

            </TouchableWithoutFeedback>
        );
    }
}))


export default Login
