import React, { Component } from "react";
import { FlatList, Image, ScrollView, StyleSheet, Text, View, Dimensions, TouchableOpacity,Linking } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import Carousel, { Pagination } from "react-native-snap-carousel";
import FastImage from 'react-native-fast-image'
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import Toast, { DURATION } from 'react-native-easy-toast';
import { observable, makeObservable } from 'mobx'
import TopBar from '../../components/topBar'
import FavouriteButton from '../../components/favouriteButton'
import Loading from '../../components/Loading';
import { colors } from '../../assets/styles/colors-theme';
import I18n from '../../services/i18n'
import CategoryList from '../../components/categoryList'
const Main = inject("appStore")(observer(class Main extends React.Component {

    randomItem = []

    constructor(props) {
        super(props);
        this.store = props.appStore
        this.state = {
            activeSlide: 0,
        };
        makeObservable(this, {
            randomItem: observable
        });
        this.genRandomItems()
    }

    sort(array) {
        return array.sort(() => Math.random() - 0.5);
    }
    async genRandomItems() {
        this.randomItem = this.sort(this.store.products)
    }


    _renderSectionHeader(title, onPress) {
        return (
            <View style={{ flexDirection: "row", marginTop: 20, marginHorizontal: 20 }}>
                <View style = {{width:10,height:'100%',backgroundColor:colors.BORDER_PINK}}/>
                <Text data-layer="6e5887c6-f6c3-4e15-82d7-45669d668c04" style={styles.home_categories}>
                    {title}
                </Text>
                {!!onPress && (
                    <View style={{ flex: 1, justifyContent: "center", alignItems: "flex-end" }}>
                        {/* <TouchableOpacity onPress={onPress}>
                            <View style={{ flexDirection: "row", alignItems: "center" }}>
                                <Text data-layer="18596a85-214e-40c1-8040-4bf02d0a8fae" style={styles.home_buttonslinkWithIcon_seeAlld83980af}>
                                    {I18n.t("homeLookAll")} >
								</Text>
                            </View>
                        </TouchableOpacity> */}
                    </View>
                )}
            </View>
        );
    }

    _renderCol(item) {
        const isCategory = true;
        const imageSrc = isCategory ? item.image ?.src : item.images ?.[0] ?.src;

        return (
            <Col>
                {!!item && (
                    <TouchableOpacity
                        style={{
                            flex: 1,
                            paddingHorizontal: 20,
                        }}
                        onPress={() => {
                            if (isCategory) {
                                // this.props.navigateTo({
                                // 	screen: "productList",
                                // 	payload: {
                                // 		name: item?.name,
                                // 		customList: this.props.api.allProducts?.filter((items) => items.categories[0].name == item?.name),
                                // 	},
                                // });
                            } else {
                                //this.props.navigateTo({ screen: "productDetails", payload: { product: item } });
                            }
                        }}
                    >
                        <Image
                            data-layer="f78fdf46-a3a6-4567-8d18-7826a5bcbe61"
                            source={{ uri: imageSrc }}
                            style={styles.homeFirstTimeLoginIn1_group2501_e59c5ae45bbfa3b8ee107e6394e04418}
                        />
                        <Text data-layer="71240a96-cfdb-4126-88e8-4523c0cd7765" style={styles.homeFirstTimeLoginIn2_product9bcf8c78}>
                            {item.name}
                        </Text>
                        {!isCategory && (
                            <Text data-layer="5d41709d-8775-43e0-ba5e-360d8b59f2c7" style={styles.homeFirstTimeLoginIn1_group2501_producteb7f0ae0}>
                                ${item.price}
                            </Text>
                        )}
                    </TouchableOpacity>
                )}
            </Col>
        );
    }

    _renderItem = ({ item, index }) => {

        return (
            <TouchableOpacity
                //disabled={!item.product}
                style={{ height: "100%", width: "100%" }}
                onPress={() => {
                   // Linking.openURL(item.landing);
                    //this.props.navigateTo({ screen: "productDetails", payload: { product: item?.product } });
                }}
            >
                <FastImage
                    source={
                        { uri: this.store.uriLink + item.mobileImage }

                    }
                    style={styles.productPageOnesreen_group2122_group2118_photo}
                />
            </TouchableOpacity>
        );
    };

    rederHotItems = ({ item, index, separators }) => {
        if (item.hotItem == '1') {
            return (
                <TouchableOpacity
                    style={{ flex: 1, marginRight: 10, }}
                    onPress={() => {
                        //this.props.navigateTo({ screen: "productDetails", payload: { product: item } });
                        this.store.goToProductDetails(item.productId, this);
                    }}
                >
                    <View
                        style={{
                            height: "100%",
                            width: 111,
                            borderTopLeftRadius: 6,
                            borderTopRightRadius: 6,
                            borderBottomLeftRadius: 6,
                            borderBottomRightRadius: 6,
                        }}
                    >
                        <FastImage
                            // source={{ uri: item?.images?.[0]?.src }}
                            source={{ uri: this.store.uriLink + item.image }}
                            style={{ width: 111, height: 111, resizeMode: "cover", borderColor: colors.BORDER_PINK, borderWidth: 1, borderRadius: 10 }}
                        />
                        <View
                            style={{

                                justifyContent: "center",
                                // alignItems: "center",
                            }}
                        >
                            <Text style={[styles.home_product80938ed2, { marginTop: 1 }]} numberOfLines={1}>
                                {item.name}
                            </Text>
                            {/* <Text style={styles.home_product80938ed3}>{item.color}</Text> */}
                            {/* <Text style={styles.home_product80938ed3}>{item.origin}</Text> */}
                            <View style={{ flexDirection: 'row', alignItems: 'center' }}>
                                <Text style={styles.home_product80938ed2}>${item.price}</Text>

                                {/* <FavouriteButton data={item} /> */}
                            </View>


                        </View>
                    </View>
                </TouchableOpacity>
            );
        }
    }

    render() {

        const { activeSlide } = this.state;

        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <Loading loading={this.store.loading} />
                <TopBar self={this} />
                <ScrollView style={{ flex: 1 }}>

                    <CategoryList data={this.store.category} self={this} />
                    {/* <View style={{ height: 35, marginTop: 0, justifyContent: "center", alignItems: "center" }}>
                     <View
                            style={{
                                height: "100%",
                                borderRadius: 10,
                                borderColor: colors.BORDER_PINK,
                                borderWidth: 1,
                                backgroundColor: "white",
                                padding: 4,
                                flexDirection: "row",
                                justifyContent: "center",
                                alignItems: "center",
                            }}
                        >
                            <Image style={{ height: "100%", resizeMode: "contain" }} source={images.ICON_BROADCAST} />
                            <Text style={{}}>《AnnChoi夜冷》正式成為FUJIFILM香港認可分銷商</Text>
                        </View> 
                    </View> */}
                    <View style={styles.productPageOnesreen_group2122_group2118}>
                        <Carousel
                            data={
                                // banners
                                this.store.banner
                            }
                            renderItem={this._renderItem}
                            onSnapToItem={(index) => this.setState({ activeSlide: index })}
                            windowSize={1}
                            layout={"default"}
                            sliderWidth={Dimensions.get("window").width}
                            itemWidth={Dimensions.get("window").width}
                            loop={true}
                            autoplay={true}
                            autoplayInterval={5000}
                            inactiveSlideScale={1}
                        />
                        <Pagination
                            dotsLength={
                                this.store.banner.length
                            }
                            activeDotIndex={activeSlide}
                            containerStyle={{
                                paddingTop: 10,
                                paddingBottom: 10,
                            }}
                            dotStyle={{
                                width: 8,
                                height: 8,
                                borderRadius: 5,
                                marginHorizontal: 0,
                                backgroundColor: colors.BORDER_PINK,
                            }}
                            inactiveDotStyle={
                                {
                                    // Define styles for inactive dots here
                                }
                            }
                            inactiveDotOpacity={0.4}
                            inactiveDotScale={0.6}
                        />
                    </View>
                    {this._renderSectionHeader(I18n.t('hotItems'), () => {
                        //this.props.navigateTo({ screen: "productList", payload: { name: I18n.t("homeFeatureProducts"), customList: featureProduct } });
                    })}
                    <FlatList
                        style={{
                            height: 230,
                            marginTop: 10,
                            paddingBottom: 20,
                        }}
                        data={this.store.products}
                        horizontal={true}
                        keyExtractor={(item) => item.productId.toString()}
                        extraData={this.store.products}
                        ListHeaderComponent={() => {
                            return <View style={{ width: 23, height: "100%" }} />;
                        }}
                        renderItem={this.rederHotItems}
                    // ItemSeparatorComponent={() => {
                    //     return <View style={{ width: 20, height: "100%" }} />;
                    // }}
                    // ListFooterComponent={() => {
                    //     return <View style={{ width: 23, height: "100%" }} />;
                    // }}
                    />
                    {this._renderSectionHeader(I18n.t("homeYouMayLike"), () => {
                        //this.props.navigateTo({ screen: "productList", payload: { name: I18n.t("homeYouMayLike"), customList: youMayLikeList } });
                    })}
                    <FlatList
                        style={{
                            height: 230,
                            marginTop: 10,
                            paddingBottom: 20,
                        }}
                        data={this.store.products}
                        horizontal={true}
                        keyExtractor={(item) => item.productId.toString()}
                        extraData={this.randomItem}
                        ListHeaderComponent={() => {
                            return <View style={{ width: 23, height: "100%" }} />;
                        }}
                        renderItem={({ item, index, separators }) => {
                            if (index < 8) {
                                return (
                                    <TouchableOpacity
                                        style={{ flex: 1 }}
                                        onPress={() => {
                                            this.store.goToProductDetails(item.productId, this);
                                        }}
                                    >
                                        <View
                                            style={{
                                                height: "100%",
                                                width: 111,
                                                borderTopLeftRadius: 6,
                                                borderTopRightRadius: 6,
                                                borderBottomLeftRadius: 6,
                                                borderBottomRightRadius: 6,
                                            }}
                                        >
                                            <FastImage
                                                // source={{ uri: item?.images?.[0]?.src }}
                                                source={{ uri: this.store.uriLink + item.image }}
                                                style={{ width: 111, height: 111, resizeMode: "cover", borderColor: colors.BORDER_PINK, borderWidth: 1, borderRadius: 10 }}
                                            />
                                            <View
                                                style={{

                                                    justifyContent: "center",
                                                    // alignItems: "center",
                                                }}
                                            >
                                                <Text style={[styles.home_product80938ed2, { marginTop: 8 }]} numberOfLines={1}>
                                                    {item.name}
                                                </Text>
                                                <View style={{ flexDirection: 'row', alignItems: 'center' }}>
                                                    <Text style={styles.home_product80938ed2}>${item.price}</Text>
                                                    {/* <FavouriteButton data={item} /> */}
                                                </View>
                                            </View>
                                        </View>
                                    </TouchableOpacity>
                                );
                            }
                        }}
                        ItemSeparatorComponent={() => {
                            return <View style={{ width: 10, height: "100%" }} />;
                        }}
                        ListFooterComponent={() => {
                            return <View style={{ width: 23, height: "100%" }} />;
                        }}
                    />

                </ScrollView>
            </View>
        );
    }
}))


const styles = StyleSheet.create({
    home_categories: {
        opacity: 1,
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "700",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        marginLeft: 5,
    },
    home_featuredProducts08bda267: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: Dimensions.get("window").width - 30 * 2,
        height: 30,
        // left: 30,
        // top: 623,
    },
    home_featuredProducts: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: Dimensions.get("window").width - 30 * 2,
        height: 30,
        // left: 30,
        // top: 885,
    },
    home_searchByBrand: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: Dimensions.get("window").width - 30 * 2,
        height: 30,
        // left: 30,
        // top: 1158.5,
    },
    home_buttonslinkWithIcon: {
        // opacity: 1,
        // position: "absolute",
        // backgroundColor: "red",
        // width: Dimensions.get("window").width - 30 * 2,
        // height: 20,
        // right: 30,
        // top: 144,
    },
    home_buttonslinkWithIcon_iconDoubleArrows83935e91: {
        opacity: 1,
        width: 8,
        height: 7.67,
    },
    home_buttonslinkWithIcon_seeAlld83980af: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "black",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "right",

        // width: 55,

        // right: 10,
        // // top: -0.5,
        marginRight: 10,
    },
    home_topDeals: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        // width: 79,
        height: 30,
        // left: 30,
        // top: 380,
    },
    home_buttonslinkWithIconCopyf5ad68d1: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: Dimensions.get("window").width - 30 * 2,
        height: 20,
        right: 30,
        // top: 381.5,
    },
    home_buttonslinkWithIconCopyf5ad68d1_iconDoubleArrowsdc40b115: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 8,
        height: 7.67,
        right: 0,
        // top: 6,
    },
    home_buttonslinkWithIconCopyf5ad68d1_seeAll1c0939e0: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(160, 87, 48, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "right",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        // width: 55,
        height: 26,
        right: 10,
        // // top: -0.5,
    },
    home_path55aad487: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 17,
        height: 157,
        // left: 359,
        // top: 422,
    },
    home_product29b03852: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 42,
        height: 26,
        // left: 72.5,
        // top: 342.5,
    },
    home_product12c9a4ce: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 70,
        height: 26,
        // left: 208.5,
        // top: 342.5,
    },
    home_product69c9f0e8: {
        opacity: 1,
        // // position: "absolute",
        // backgroundColor: "rgba(255, 255, 55, 1)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        // textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        // width: 42,

        // // left: 364.5,
        // // top: 342.5,
    },
    home_price0f40fa4b: {
        opacity: 1,
        // // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
    },
    home_product80938ed2: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 13,
        fontWeight: "bold",
        fontFamily: "Avenir",
    },
    home_product80938ed3: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 12,
        fontFamily: "Avenir",
    },
    home_price2b46c4b5: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 58,
        height: 29,
        // left: 155.5,
        // top: 848.5,
    },
    home_productf9be3ac6: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 72,
        height: 25,
        // left: 148.5,
        // top: 820.5,
    },
    home_price4f4dec9f: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 58,
        height: 29,
        // left: 305.5,
        // top: 848.5,
    },
    home_product187b03a5: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 70,
        height: 25,
        // left: 299.5,
        // top: 820.5,
    },
    home_product2a9f6f2a: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 106,
        height: 25,
        // left: 300,
        // top: 1311.5,
    },
    home_product94ec47bb: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 52,
        height: 25,
        // left: 193,
        // top: 1311.5,
    },
    home_product8889d9bc: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 102,
        height: 25,
        // left: 27,
        // top: 1311.5,
    },
    home_group2110: {
        opacity: 1,
        backgroundColor: "transparent",
        width: Dimensions.get("window").width - 40,
        height: 160,
    },
    home_group2110_rectangle: {
        opacity: 1,
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        borderBottomLeftRadius: 6,
        borderBottomRightRadius: 6,
        width: "100%",
        height: 159,
    },
    home_group2110_rolexOysterPerpetu: {
        opacity: 1,
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(255, 255, 255, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
    },
    home_group2110_xc13931ad: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(255, 255, 255, 1)",
        fontSize: 24,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // height: 35,
        // top: 112,
    },
    home_group2110_x39MmOystersteel: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(255, 255, 255, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // top: 51,
    },
    home_buttonslinkWithIconCopy871b9042: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: Dimensions.get("window").width - 30 * 2,
        height: 20,
        right: 30,
        // top: 624.5,
    },
    home_buttonslinkWithIconCopy871b9042_iconDoubleArrowsf0d3c625: {
        opacity: 1,
        // position: "absolute",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 8,
        height: 7.67,
        right: 0,
        // top: 6,
    },
    home_buttonslinkWithIconCopy871b9042_seeAll1aaf54be: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(160, 87, 48, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "right",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        // width: 55,
        height: 26,
        right: 10,
        // // top: -0.5,
    },
    home_buttonslinkWithIconCopy95708fc7: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: Dimensions.get("window").width - 30 * 2,
        height: 20,
        right: 30,
        // top: 890.5,
    },

    home_buttonslinkWithIconCopy: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: Dimensions.get("window").width - 30 * 2,
        height: 20,
        right: 30,
        // top: 1157.5,
    },
 

    home_group2131: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "transparent",
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 440,
        height: 199,
        // left: -17,
        // top: 927,
    },


    home_group2131_price: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 20,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "left",
        // lineHeight: 22,
        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 58,
        height: 29,
        // left: 336.5,
        // top: 174.5,
    },
    home_group2131_product: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",

        // marginTop: 0,
        // marginRight: 0,
        // marginBottom: 0,
        // marginLeft: 0,
        // paddingTop: 0,
        // paddingRight: 0,
        // paddingBottom: 0,
        // paddingLeft: 0,
        width: 84,
        height: 25,
        // left: 323.5,
        // top: 146.5,
    },


    homeFirstTimeLoginIn1_group2501_e59c5ae45bbfa3b8ee107e6394e04418: {
        borderTopLeftRadius: 6,
        borderTopRightRadius: 6,
        borderBottomLeftRadius: 6,
        borderBottomRightRadius: 6,
        width: "100%",
        // height: 160,
        aspectRatio: 1,
        resizeMode: "cover",
        marginVertical: 10,
    },
    homeFirstTimeLoginIn1_group2501_producteb7f0ae0: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "600",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",
        height: 26,
    },
    homeFirstTimeLoginIn2_product9bcf8c78: {
        opacity: 1,
        // position: "absolute",
        backgroundColor: "rgba(255, 255, 255, 0)",
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontWeight: "100",
        fontStyle: "normal",
        fontFamily: "Avenir",
        textAlign: "center",
    },
    productPageOnesreen_group2122_group2118_photo: {
        opacity: 1,
        width: "100%",
        height: "100%",
        resizeMode: "cover",
        // borderRadius: 10,
    },
    productPageOnesreen_group2122_group2118: {
        width: Dimensions.get("window").width,
        height: 135,
        marginTop: 0,
    },
});

export default Main