import React, { Component } from "react";
import { Image as ReactImage, ScrollView, Text, View, TouchableOpacity, TextInput, Platform } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import FastImage from 'react-native-fast-image'
import TopBar from '../../components/topBar'
import Toast, { DURATION } from 'react-native-easy-toast';
import TitleBar from '../../components/titleBar'
var _ = require('lodash');
import Loading from '../../components/Loading';
import { width, height } from '../../services/screen'
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import { colors } from '../../assets/styles/colors-theme';
import { getStatusBarHeight } from 'react-native-status-bar-height';
import I18n from '../../services/i18n'
import Icon from 'react-native-vector-icons/dist/AntDesign';
import GoogleIcon from 'react-native-vector-icons/dist/MaterialCommunityIcons'
import Menu, {
    MenuProvider,
    MenuTrigger,
    MenuOptions,
    MenuOption,
    renderers,
} from 'react-native-popup-menu';
import moment from "moment";
const { SlideInMenu } = renderers;
import CheckBox from "@react-native-community/checkbox";

const ConfirmPayment = inject("appStore")(observer(class ConfirmPayment extends React.Component {

    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {

        });
    }

    confirmAction() {
        const paymentMethod = this.props.route.params.paymentType
        switch (paymentMethod) {
            case 0:
                // return I18n.t('payme_alipay_wechat')
                this.store.payByOther(this);
                break;
            case 1:
                // return I18n.t('payCashAtStore')
                this.store.payByCash(this);
                break;
            case 2:
                //  return I18n.t('creditCardPayment')
                this.store.payByStripe(this);
                break;
            case 3:
                //  return I18n.t('payPalPayment')
                this.store.payByPalPal(this);
                break;

        }
    }

    totalPrice() {
        const items = this.props.route.params.orderData.item
        const couponData = this.props.route.params.orderData.couponData
        var total = 0
        Promise.all(items.map((item, index) => {
            total += item.price * item.qty
        }))
        if (couponData != null) {
            if (couponData.couponType == 'fix') {
                total = total - parseInt(couponData.couponValue)
            } else {
                total = (total * (100 - parseInt(couponData.couponValue))) / 100
            }
        }
        return total.toFixed(1)
    }

    shippingTextHandler() {
        const shippingMethod = this.store.paymentData.shipping.delivery

        if (shippingMethod == 1) {
            return I18n.t('pickUpAtTheStore')
        } else {
            return I18n.t('sfShipping')
        }
    }

    paymentTextHandler() {
        const paymentMethod = this.props.route.params.paymentType
        switch (paymentMethod) {
            case 0:
                return I18n.t('payme_alipay_wechat')
                break;
            case 1:
                return I18n.t('payCashAtStore')
                break;
            case 2:
                return I18n.t('creditCardPayment')
                break;
            case 3:
                return I18n.t('payPalPayment')
                break;

        }
    }


    render() {

        // const product = this.props.navigator.payloadForScreen?.[this.getScreenName()]?.product;

        const name = I18n.t('cartConfirmOrder');


        const items = this.props.route.params.orderData.item

        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <Loading loading={this.store.loading} />
                <View style={{ width: width, height: 50, justifyContent: 'center', alignItems: 'center', flexDirection: 'row', marginTop: Platform.OS === 'ios' ? getStatusBarHeight() : getStatusBarHeight(), }}>

                    <Text
                        numberOfLines={1}
                        style={{
                            width: width / 1.5,
                            textAlign: "center",
                            color: "black",
                            fontSize: 18,
                            fontWeight: this.props.bold ? '800' : '100',
                            fontStyle: "normal",
                            fontFamily: "Avenir",
                        }}
                    >
                        {name}
                    </Text>
                    <TouchableOpacity style={{ position: 'absolute', left: 20 }} onPress={() => { this.props.navigation.goBack() }}>
                        <Icon name='arrowleft' size={20} />
                    </TouchableOpacity>
                </View>
                <View
                    style={{
                        flexDirection: "row",
                        height: 35,
                        justifyContent: "center",
                        alignItems: "center",
                        marginTop: 10,
                        // marginTop: Platform.OS === 'ios' ? 0 : getStatusBarHeight(),
                    }}
                >
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_DIM,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>1</Text>
                        </View>
                        <Text style={{ fontSize: 12 }}>{I18n.t('shipping')}</Text>
                    </View>

                    <View style={{ width: 50, height: 1, borderColor: colors.BORDER_DIM, borderWidth: 1, marginHorizontal: 10, marginBottom: 10 }} />
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_DIM,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>2</Text>
                        </View>
                        <Text style={{ fontSize: 12 }}>{I18n.t('paymentMethods')}</Text>
                    </View>
                    <View style={{ width: 50, height: 1, borderColor: colors.BORDER_DIM, borderWidth: 1, marginHorizontal: 10, marginBottom: 10 }} />
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_PINK,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>3</Text>
                        </View>
                        <Text style={{ color: colors.BORDER_PINK, fontSize: 12 }}>{I18n.t('confirm')}</Text>
                    </View>
                </View>
                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>



                    <View style={{ marginHorizontal: 20, marginTop: 10 }}>
                        <View style={{ paddingHorizontal: 0, marginTop: 5 }}>
                            <View style={{ flexDirection: "row" }}>
                                <Text style={{ flex: 4, paddingLeft: 15 }}>{''}</Text>
                                <Text style={{ flex: 1 }}>{I18n.t('price')}</Text>
                            </View>
                            <View style={{ flex: 1, height: 0, borderTopColor: "black", borderTopWidth: 1, marginVertical: 5 }} />
                            {items.map((item, index) => {
                                return (
                                    <View style={{ flexDirection: "row", paddingLeft: 10, marginVertical: 10 }}>
                                        <View style={{ flex: 4, flexDirection: "row" }}>
                                            <Text style={{ width: 15 }}>{index + 1}</Text>
                                            <FastImage
                                                // source={{ uri: item?.images?.[0]?.src }}
                                                source={{ uri: this.store.uriLink + item.image }}
                                                style={{
                                                    width: 60,
                                                    height: 60,
                                                    marginRight: 5,
                                                    resizeMode: "cover",
                                                    borderColor: colors.BORDER_PINK,
                                                    borderWidth: 1,
                                                    borderRadius: 10,
                                                }}
                                            />
                                            <View style={{ flex: 1 }}>
                                                <Text
                                                    style={{
                                                        color: "rgba(39, 40, 51, 1)",
                                                        fontSize: 13,
                                                        fontFamily: "Avenir",
                                                    }}
                                                >
                                                    {item?.name}
                                                </Text>
                                                {item.option != null ? (<View>
                                                    <Text style={{
                                                        color: "rgba(39, 40, 51, 1)",
                                                        fontSize: 13,
                                                        fontFamily: "Avenir",
                                                    }}>
                                                        {item.option.name}
                                                    </Text>
                                                </View>) : (<View />)}
                                            </View>
                                        </View>
                                        <View style={{ flex: 1 }}>
                                            <Text
                                                style={{
                                                    color: "rgba(39, 40, 51, 1)",
                                                    fontSize: 13,
                                                    fontFamily: "Avenir",
                                                }}
                                            >
                                                ${parseFloat(item.price) * parseFloat(item.qty)}
                                            </Text>
                                        </View>
                                    </View>
                                );
                            })}
                            <View style={{ flex: 1, height: 0, borderTopColor: "black", borderTopWidth: 1, marginVertical: 5 }} />
                            <View style={{ flexDirection: "row" }}>
                                <View style={{ flex: 0.75 }} />
                                <View style={{ flex: 0.25 }}>
                                    {this.props.route.params.orderData.couponData != null ? (
                                        <Text>
                                            {'- ' + this.props.route.params.orderData.couponData.couponValue + (this.props.route.params.orderData.couponData.couponType == 'fix' ? ' HKD' : ' %')}
                                        </Text>
                                    ) : (<View />)}
                                    <Text>{I18n.t("totalPrice")}</Text>
                                    <Text>{"HK$ " + this.totalPrice()}</Text>
                                </View>
                            </View>
                            <Text style={{ marginTop: 10 }}>{I18n.t('info')}</Text>
                            <Text style={{ marginTop: 5 }}>{I18n.t('cartRecipientName') + ": " + this.store.paymentData.shipping.name}</Text>
                            <Text>{I18n.t('settingsPhoneNumber') + ": " + this.store.paymentData.shipping.phone}</Text>
                            <Text>{I18n.t('loginEmail') + ": " + this.store.paymentData.shipping.email}</Text>
                            <Text style={{ marginTop: 20 }}>{I18n.t('shippingMethods')}</Text>
                            <Text style={{ marginTop: 5 }}>{this.shippingTextHandler()}</Text>
                            <Text>{I18n.t('cartAddress') + ": " + this.store.paymentData.shipping.address}</Text>
                            <Text style={{ marginTop: 20 }}>{I18n.t('orderDetailsPaymentMethod')}</Text>
                            <Text style={{ marginTop: 5 }}>{this.paymentTextHandler()}</Text>
                        </View>
                        <TouchableOpacity
                            onPress={() => {
                                this.confirmAction()
                            }}
                        >
                            <View
                                style={{
                                    width: "100%",
                                    height: 40,
                                    marginVertical: 40,
                                    borderRadius: 8,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: colors.BORDER_PINK,
                                }}
                            >
                                <Text style={{ color: "white" }}>{I18n.t('confirmOrder')}</Text>
                            </View>
                        </TouchableOpacity>
                    </View>
                </ScrollView>
            </View>
        );
    }
}))

export default ConfirmPayment