import React, { Component } from "react";
import { Image as ReactImage, ScrollView, Text, View, TouchableOpacity, TextInput, Platform } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import FastImage from 'react-native-fast-image'
import TopBar from '../../components/topBar'
import Toast, { DURATION } from 'react-native-easy-toast';
import TitleBar from '../../components/titleBar'
var _ = require('lodash');
import { width, height } from '../../services/screen'
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import { colors } from '../../assets/styles/colors-theme';
import { getStatusBarHeight } from 'react-native-status-bar-height';
import { launchCamera, launchImageLibrary } from 'react-native-image-picker';
import I18n from '../../services/i18n'
import Icon from 'react-native-vector-icons/dist/AntDesign';
import GoogleIcon from 'react-native-vector-icons/dist/MaterialCommunityIcons'
import Menu, {
    MenuProvider,
    MenuTrigger,
    MenuOptions,
    MenuOption,
    renderers,
} from 'react-native-popup-menu';
import moment from "moment";
const { SlideInMenu } = renderers;
import CheckBox from "@react-native-community/checkbox";

const PaymentMethod = inject("appStore")(observer(class PaymentMethod extends React.Component {

    PaymentType = 0
    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {
            PaymentType: observable
        });
    }
    saveImageHandler(image) {
        var photoId = this.store.idGenerator();
        console.log(photoId);
        return {
            id: photoId,
            name: photoId + '.jpg',
            createDate: new Date(),
            uri: image.uri,
            mime: image.type,
            height: image.height,
            width: image.width,
        };
    }


    saveAndroidImageHandler(image) {
        var photoId = this.store.idGenerator();
        return {
            id: photoId,
            name: photoId + '.jpg',
            createDate: new Date(),
            uri: image.uri,
            mime: image.type,
            height: image.height,
            width: image.width,
        };
    }


    renderRadioButton(value) {
        return (
            <TouchableOpacity onPress={() => {
                if (this.PaymentType != value) {
                    this.PaymentType = value
                }
            }}>
                <GoogleIcon size={20} name={this.PaymentType == value ? 'circle-slice-8' : 'circle-outline'} color={this.PaymentType == value ? colors.BORDER_PINK : colors.BORDER_DIM} />
            </TouchableOpacity>
        )
    }



    render() {

        const name = I18n.t('selectPaymentMethod');



        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <View style={{ width: width, height: 50, justifyContent: 'center', alignItems: 'center', flexDirection: 'row', marginTop: Platform.OS === 'ios' ? getStatusBarHeight() : getStatusBarHeight(), }}>

                    <Text
                        numberOfLines={1}
                        style={{
                            width: width / 1.5,
                            textAlign: "center",
                            color: "black",
                            fontSize: 18,
                            fontWeight: this.props.bold ? '800' : '100',
                            fontStyle: "normal",
                            fontFamily: "Avenir",
                        }}
                    >
                        {name}
                    </Text>
                    <TouchableOpacity style={{ position: 'absolute', left: 20 }} onPress={() => { this.props.navigation.goBack() }}>
                        <Icon name='arrowleft' size={20} />
                    </TouchableOpacity>
                </View>
                <View
                    style={{
                        flexDirection: "row",
                        height: 35,
                        justifyContent: "center",
                        alignItems: "center",
                        marginTop: 10,
                        // marginTop: Platform.OS === 'ios' ? 0 : getStatusBarHeight(),
                    }}
                >
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_DIM,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>1</Text>
                        </View>
                        <Text style={{ fontSize: 12 }}>{I18n.t('shipping')}</Text>
                    </View>

                    <View style={{ width: 50, height: 1, borderColor: colors.BORDER_DIM, borderWidth: 1, marginHorizontal: 10, marginBottom: 10 }} />
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_PINK,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>2</Text>
                        </View>
                        <Text style={{ color: colors.BORDER_PINK, fontSize: 12 }}>{I18n.t('paymentMethods')}</Text>
                    </View>
                    <View style={{ width: 50, height: 1, borderColor: colors.BORDER_DIM, borderWidth: 1, marginHorizontal: 10, marginBottom: 10 }} />
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_DIM,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>3</Text>
                        </View>
                        <Text style={{ fontSize: 12 }}>{I18n.t('confirm')}</Text>
                    </View>
                </View>

                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>


                    <View style={{ marginHorizontal: 40, marginTop: 10 }}>
                        <View style={{ flexDirection: "row", marginTop: 10 }}>
                            {this.renderRadioButton(0)}
                            <View>
                                <Text style={{ marginTop: 2, marginLeft: 5 }}>
                                    {I18n.t('payme_alipay_wechat')}
                                </Text>
                                <TouchableOpacity onPress={() => { this.props.navigation.navigate('ShowQrcode', { data: 'wechat' }) }}>
                                    <Text style={{ color: colors.BORDER_PINK }}>
                                        {I18n.t('getWechatQrcode')}
                                    </Text>
                                </TouchableOpacity>
                                <TouchableOpacity onPress={() => { this.props.navigation.navigate('ShowQrcode', { data: 'payme' }) }}>
                                    <Text style={{ color: colors.BORDER_PINK }}>
                                        {I18n.t('getPayMeQrcode')}
                                    </Text>
                                </TouchableOpacity>
                                <TouchableOpacity onPress={() => { this.props.navigation.navigate('ShowQrcode', { data: 'alipay' }) }}>
                                    <Text style={{ color: colors.BORDER_PINK }}>
                                        {I18n.t('getAliPayQrcode')}
                                    </Text>
                                </TouchableOpacity>

                                {this.PaymentType == 0 ? (<View style={{ width: 250 }}>
                                    <Text style={{ marginTop: 8 }}>{I18n.t('uploadReceiptOfPayment') + ":"}</Text>
                                    {this.store.uploadImage != null ? (
                                        <FastImage
                                            style={{
                                                width: 250,
                                                height: 250,
                                                marginTop: 20,
                                                borderRadius: 40,
                                                borderWidth: 1,
                                                borderColor: colors.BORDER_PINK,
                                                justifyContent: 'center',
                                                alignItems: 'center',
                                            }}
                                            source={{ uri: this.store.uploadImage.uri }}
                                        />
                                    ) : (
                                            <View
                                                style={{
                                                    width: 250,
                                                    height: 250,
                                                    marginTop: 20,
                                                    borderRadius: 40,
                                                    borderWidth: 1,
                                                    borderColor: colors.BORDER_PINK,
                                                    justifyContent: 'center',
                                                    alignItems: 'center',
                                                }}>
                                                <GoogleIcon
                                                    name="image-plus"
                                                    size={40}
                                                    color={colors.BORDER_DIM}
                                                />

                                            </View>
                                        )}

                                    <View style={{ flexDirection: "row" }}>
                                        <View style={{ flex: 1 }} />
                                        <TouchableOpacity
                                            onPress={() => {
                                                launchImageLibrary({ mediaType: 'photo', includeBase64: false, }, response => {
                                                    console.info(response);
                                                    //var response = image;

                                                    if (Platform.OS === 'ios') {
                                                        this.store.uploadImage = this.saveImageHandler(response.assets[0]);
                                                        console.log(this.store.uploadImage);
                                                    } else {
                                                        this.store.uploadImage = this.saveAndroidImageHandler(response.assets[0]);
                                                    }
                                                });
                                            }}
                                        >
                                            <View
                                                style={{
                                                    width: 60,
                                                    height: 25,
                                                    marginTop: 5,
                                                    borderRadius: 8,
                                                    justifyContent: "center",
                                                    alignItems: "center",
                                                    backgroundColor: colors.BORDER_PINK,
                                                }}
                                            >
                                                <Text style={{ color: "white" }}>{I18n.t('upload')}</Text>
                                            </View>
                                        </TouchableOpacity>
                                    </View>
                                </View>) : (<View />)}

                            </View>
                        </View>

                        {this.store.paymentData.shipping.delivery == 2 ? (<View />) : (<View style={{ flexDirection: "row", marginTop: 10 }}>
                            {this.renderRadioButton(1)}
                            <Text style={{ marginTop: 2, marginLeft: 5 }}>{I18n.t('payCashAtStore') + "\n新界葵涌華星街8號華達工業中心\nB座"}</Text>
                        </View>)}


                        <View style={{ flexDirection: "row", marginTop: 10 }}>
                            {this.renderRadioButton(2)}
                            <View style={{ marginTop: 2, marginLeft: 5 }}>
                                <Text>{I18n.t('creditCardPayment')}</Text>


                            </View>
                        </View>
                        <View style={{ flexDirection: "row", marginTop: 10 }}>
                            {this.renderRadioButton(3)}
                            <Text>{I18n.t('payPalPayment')}</Text>
                        </View>
                        <TouchableOpacity
                            onPress={() => {
                      
                                if (this.PaymentType === 0) {
                                    if (this.store.uploadImage != null) {
                                        this.props.navigation.navigate('ConfirmPayment', { orderData: this.props.route.params.orderData, paymentType: this.PaymentType })
                                    } else {
                                        this.refs.toast.show(I18n.t('uploadReceiptOfPayment'))
                                    }
                                } else {
                                    this.props.navigation.navigate('ConfirmPayment', { orderData: this.props.route.params.orderData, paymentType: this.PaymentType })
                                }
                            }}
                        >
                            <View
                                style={{
                                    width: "100%",
                                    height: 40,
                                    marginVertical: 40,
                                    borderRadius: 8,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: colors.BORDER_PINK,
                                }}
                            >
                                <Text style={{ color: "white" }}>{I18n.t('next')}</Text>
                            </View>
                        </TouchableOpacity>
                    </View>
                </ScrollView >
                <Toast
                    ref="toast"
                    style={{ backgroundColor: colors.BORDER_PINK }}
                    position="center"
                    positionValue={200}
                    fadeInDuration={750}
                    fadeOutDuration={2000}
                    opacity={0.8}
                    textStyle={{ color: 'white' }}
                />
            </View >
        );
    }
}))
export default PaymentMethod