import React, { Component } from "react";
import { Image as ReactImage, ScrollView, Text, View, TouchableOpacity, TextInput, Platform } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import FastImage from 'react-native-fast-image'
import TopBar from '../../components/topBar'
import Toast, { DURATION } from 'react-native-easy-toast';
import TitleBar from '../../components/titleBar'
var _ = require('lodash');
import { width, height } from '../../services/screen'
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import { colors } from '../../assets/styles/colors-theme';
import { getStatusBarHeight } from 'react-native-status-bar-height';
import I18n from '../../services/i18n'
import Icon from 'react-native-vector-icons/dist/AntDesign';
import GoogleIcon from 'react-native-vector-icons/dist/MaterialCommunityIcons'
import Menu, {
    MenuProvider,
    MenuTrigger,
    MenuOptions,
    MenuOption,
    renderers,
} from 'react-native-popup-menu';
import moment from "moment";
const { SlideInMenu } = renderers;
import CheckBox from "@react-native-community/checkbox";

const Shipping = inject("appStore")(observer(class Shipping extends React.Component {

    shippingType = 2
    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {
            shippingType: observable
        });

    }

    goToPaymentMethodAction() {
        const data = this.store.paymentData.shipping
        if (data.name != '' && data.phone != '' && data.email != '') {
            if (data.delivery == 1) {
                this.props.navigation.navigate('PaymentMethod', { orderData: this.props.route.params.orderData })
            } else {
                if (data.address != '') {
                    this.props.navigation.navigate('PaymentMethod', { orderData: this.props.route.params.orderData })
                } else {
                    this.refs.toast.show('Please input address')
                }
            }
        } else {
            this.refs.toast.show('Please input name, phone and email')
        }
    }

    render() {

        const name = I18n.t('shippingMethods');

        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <View style={{ width: width, height: 50, justifyContent: 'center', alignItems: 'center', flexDirection: 'row', marginTop: Platform.OS === 'ios' ? getStatusBarHeight() : getStatusBarHeight(), }}>

                    <Text
                        numberOfLines={1}
                        style={{
                            width: width / 1.5,
                            textAlign: "center",
                            color: "black",
                            fontSize: 18,
                            fontWeight: this.props.bold ? '800' : '100',
                            fontStyle: "normal",
                            fontFamily: "Avenir",
                        }}
                    >
                        {name}
                    </Text>
                    <TouchableOpacity style={{ position: 'absolute', left: 20 }} onPress={() => { this.props.navigation.goBack() }}>
                        <Icon name='arrowleft' size={20} />
                    </TouchableOpacity>
                </View>
                <View
                    style={{
                        flexDirection: "row",
                        height: 35,
                        justifyContent: "center",
                        alignItems: "center",
                        marginTop: 10,
                        // marginTop: Platform.OS === 'ios' ? 0 : getStatusBarHeight(),
                    }}
                >
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_PINK,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>1</Text>
                        </View>
                        <Text style={{ color: colors.BORDER_PINK, fontSize: 12 }}>{I18n.t('shipping')}</Text>
                    </View>

                    <View style={{ width: 50, height: 1, borderColor: colors.BORDER_DIM, borderWidth: 1, marginHorizontal: 10, marginBottom: 10 }} />
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_DIM,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>2</Text>
                        </View>
                        <Text style={{ fontSize: 12 }}>{I18n.t('paymentMethods')}</Text>
                    </View>
                    <View style={{ width: 50, height: 1, borderColor: colors.BORDER_DIM, borderWidth: 1, marginHorizontal: 10, marginBottom: 10 }} />
                    <View style={{ width: 60, justifyContent: 'center', alignItems: 'center' }}>
                        <View
                            style={{
                                backgroundColor: colors.BORDER_DIM,
                                borderRadius: 30,
                                justifyContent: "center",
                                alignItems: "center",
                                width: 35,
                                height: 35,
                            }}
                        >
                            <Text style={{ color: "white", fontSize: 15 }}>3</Text>
                        </View>
                        <Text style={{ fontSize: 12 }}>{I18n.t('confirm')}</Text>
                    </View>
                </View>

                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>

                    <View style={{ marginHorizontal: 40, marginTop: 10 }}>
                        <Text style={{ fontSize: 16 }}>{I18n.t('settingsName')}</Text>
                        <TextInput
                            style={{
                                width: "100%",
                                height: 35,
                                marginTop: 5,
                                borderColor: colors.BORDER_PINK,
                                borderWidth: 1,
                                borderRadius: 4,
                                justifyContent: "center",
                                alignItems: "center",
                                backgroundColor: "white",
                                fontSize: 12,
                                paddingHorizontal: 7,
                            }}
                            placeholder={I18n.t('editNameBoardSubTitle')}
                            value={this.store.paymentData.shipping.name}
                            onChangeText={text => this.store.paymentData.shipping.name = text}
                        />
                    </View>
                    <View style={{ marginHorizontal: 40, marginTop: 10 }}>
                        <Text style={{ fontSize: 16 }}>{I18n.t('userPhone')}</Text>
                        <TextInput
                            style={{
                                width: "100%",
                                height: 35,
                                marginTop: 5,
                                borderColor: colors.BORDER_PINK,
                                borderWidth: 1,
                                borderRadius: 4,
                                justifyContent: "center",
                                alignItems: "center",
                                backgroundColor: "white",
                                fontSize: 12,
                                paddingHorizontal: 7,
                            }}
                            placeholder={I18n.t('pleaseEnterPhone')}
                            keyboardType={'number-pad'}
                            value={this.store.paymentData.shipping.phone}
                            onChangeText={text => this.store.paymentData.shipping.phone = text}
                        />
                    </View>
                    <View style={{ marginHorizontal: 40, marginTop: 10 }}>
                        <Text style={{ fontSize: 16 }}>{I18n.t('loginEmail')}</Text>
                        <TextInput
                            style={{
                                width: "100%",
                                height: 35,
                                marginTop: 5,
                                borderColor: colors.BORDER_PINK,
                                borderWidth: 1,
                                borderRadius: 4,
                                justifyContent: "center",
                                alignItems: "center",
                                backgroundColor: "white",
                                fontSize: 12,
                                paddingHorizontal: 7,
                            }}
                            placeholder={I18n.t('pleaseEnterEmail')}
                            value={this.store.paymentData.shipping.email}
                            onChangeText={text => this.store.paymentData.shipping.email = text}
                        />
                    </View>
                    <View style={{ marginHorizontal: 40, marginTop: 10 }}>
                        <Text style={{ fontSize: 16 }}>{I18n.t('shippingMethods')}</Text>
                        <View style={{ flexDirection: "row", marginTop: 10 }}>
                            {/* <CheckBox
                                style={{ width: 20, height: 20 }}
                                disabled={false}
                                value={this.store.paymentData.shipping.delivery === 1}
                                onValueChange={(value) => this.store.paymentData.shipping.delivery = 1}
                            /> */}
                            <TouchableOpacity onPress={() => {
                                if (this.store.paymentData.shipping.delivery != 1) {
                                    this.store.paymentData.shipping.delivery = 1
                                }
                            }}>
                                <GoogleIcon size={20} name={this.store.paymentData.shipping.delivery == 1 ? 'circle-slice-8' : 'circle-outline'} color={this.store.paymentData.shipping.delivery == 1 ? colors.BORDER_PINK : colors.BORDER_DIM} />
                            </TouchableOpacity>
                            <Text style={{ marginTop: 2, marginLeft: 5 }}>{I18n.t('pickUpAtTheStore') + "\n葵涌華星街8號華達工業中心\nB座1216室"}</Text>
                        </View>
                        <View style={{ flexDirection: "row", marginTop: 10 }}>
                            <TouchableOpacity onPress={() => {
                                if (this.store.paymentData.shipping.delivery != 2) {
                                    this.store.paymentData.shipping.delivery = 2
                                }
                            }}>
                                <GoogleIcon size={20} name={this.store.paymentData.shipping.delivery == 2 ? 'circle-slice-8' : 'circle-outline'} color={this.store.paymentData.shipping.delivery == 2 ? colors.BORDER_PINK : colors.BORDER_DIM} />
                            </TouchableOpacity>
                            {/* <CheckBox
                                style={{ width: 20, height: 20 }}
                                disabled={false}
                                value={this.store.paymentData.shipping.delivery === 2}
                                onValueChange={(value) => { this.store.paymentData.shipping.delivery = 2; console.log(this.store.paymentData.shipping.delivery) }}
                            /> */}
                            <View style={{ marginTop: 2, marginLeft: 5 }}>
                                <Text>{I18n.t('sfShipping')}</Text>
                                <View style={{
                                    width: 240, height: 100, marginTop: 5,
                                    borderColor: colors.BORDER_PINK,
                                    borderWidth: 1,
                                    borderRadius: 4,
                                    backgroundColor: "white",
                                    fontSize: 12,
                                    paddingHorizontal: 7,
                                    paddingVertical: 5,
                                }}>
                                    <TextInput
                                        style={{
                                            width: 220,
                                            fontSize: 12,
                                            margin: 5
                                        }}
                                        placeholder={I18n.t('orderDetailsDeliveryAddress')}
                                        numberOfLines={4}
                                        multiline={true}
                                        textAlignVertical={"top"}
                                        value={this.store.paymentData.shipping.address}
                                        onChangeText={text => this.store.paymentData.shipping.address = text}
                                    />
                                </View>

                            </View>
                        </View>
                        <TouchableOpacity
                            onPress={() => {
                                this.goToPaymentMethodAction()
                            }}
                        >
                            <View
                                style={{
                                    width: "100%",
                                    height: 40,
                                    marginVertical: 40,
                                    borderRadius: 8,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: colors.BORDER_PINK,
                                }}
                            >
                                <Text style={{ color: "white" }}>{I18n.t('next')}</Text>
                            </View>
                        </TouchableOpacity>
                    </View>
                </ScrollView>
                <Toast
                    ref="toast"
                    style={{ backgroundColor: colors.BORDER_PINK }}
                    position="center"
                    positionValue={200}
                    fadeInDuration={750}
                    fadeOutDuration={2000}
                    opacity={0.8}
                    textStyle={{ color: 'white' }}
                />
            </View>
        );
    }
}))

export default Shipping