import React, { Component } from "react";
import { FlatList, Image, ScrollView, Share, StyleSheet, Text, View, TouchableOpacity, TextInput } from "react-native";
import Carousel, { Pagination } from "react-native-snap-carousel";
import { WebView } from "react-native-webview";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import FastImage from 'react-native-fast-image'
import Toast, { DURATION } from 'react-native-easy-toast'
import FavouriteButton from '../../components/favouriteButton'
import YoutubePlayer from "react-native-youtube-iframe";
import { colors } from '../../assets/styles/colors-theme';
import { width, height } from '../../services/screen'
import TopBar from '../../components/topBar'
import { images } from "../../assets/images/index";
import I18n from '../../services/i18n'
import TitleBar from '../../components/titleBar'
import HTMLView from 'react-native-htmlview';
import Menu, {
    MenuProvider,
    MenuTrigger,
    MenuOptions,
    MenuOption,
    renderers,
} from 'react-native-popup-menu';
const { SlideInMenu } = renderers;

const itemColor = ['Vintage', 'Cyber']

const ProductsDetails = inject("appStore")(observer(class ProductsDetails extends React.Component {
    data = this.props.route.params.data;
    itemColorSelected = itemColor[0]
    itemQtySelected = 1
    itemOption = null
    itemQty = []
    randomItem = []

    constructor(props) {
        super(props);
        this.store = props.appStore
        this.state = { activeSlide: 0 };
        makeObservable(this, {
            data: observable,
            itemColorSelected: observable,
            itemQtySelected: observable,
            randomItem: observable,
            itemOption: observable,
        });
        for (var i = 1; i <= 30; i++) {
            this.itemQty.push(i)
        }
        console.log(this.data)
        this.getQty()
        //this.getOption()
        this.genRandomItems()

        // if (this.data.youtube != '') {
        //     const data = {
        //         youtube: this.data.youtube
        //     }
        //     this.data.album.splice(0, 0, data);
        // }
    }

    async componentDidMount() {
        await this.getOption()
    }

    sort(array) {
        return array.sort(() => Math.random() - 0.5);
    }
    async genRandomItems() {
        var data = []
        Promise.all(this.store.products.map((item, index) => {
            if (this.data.categoryId == item.categoryId) {
                data.push(item)
            }
        }))
        this.randomItem = this.sort(data)

    }

    async getQty() {
        itemIndex = -1
        itemIndex = await this.store.shoppingCart.findIndex(e => e.id == this.data.productId)
        console.info(itemIndex)
        if (itemIndex > -1) {
            this.itemQtySelected = this.store.shoppingCart[itemIndex].qty
        }
    }

    async getOption() {
        itemIndex = -1
        itemIndex = await this.store.shoppingCart.findIndex(e => e.id == this.data.productId)
        console.info(itemIndex)
        if (itemIndex > -1) {
            //this.itemOption = this.store.shoppingCart[itemIndex].option
            var itemOptionsIndex = await this.data.options.findIndex((optionIndex) => optionIndex.productOptionsId == this.store.shoppingCart[itemIndex].option.productOptionsId)
            console.info(itemOptionsIndex)
            if (itemOptionsIndex != -1) {

                this.itemOption = this.data.options[itemOptionsIndex]
            } else {
                this.itemOption = this.data.options[0]
            }
        } else {
            this.itemOption = this.data.options[0]
        }
        //this.itemOption = this.data.options[0]
    }


    _renderItem = ({ item, index }) => {
        return (
            <View

                style={{ height: "100%", width: "100%" }}

            >
                <View
                    style={{
                        width: "100%",
                        alignItems: "center",
                        paddingHorizontal: 20,
                    }}
                >
                    {item.hasOwnProperty('youtube') ? (
                        <View style={{
                            width: "100%",
                            height: "100%",
                            resizeMode: "cover",
                            borderColor: colors.BORDER_PINK,
                            borderWidth: 1,
                            borderRadius: 10,
                        }}>
                            <YoutubePlayer
                                //height={300}
                                height={'100%'}
                                width={'100%'}
                                play={false}
                                videoId={this.YouTubeGetID(item.youtube)}
                                onChangeState={'play'}
                            />
                        </View>) : (<FastImage
                            source={{ uri: this.store.uriLink + item.image }}
                            style={{
                                width: "100%",
                                height: "100%",
                                resizeMode: "cover",
                                borderColor: colors.BORDER_PINK,
                                borderWidth: 1,
                                borderRadius: 10,
                            }}
                        />)}

                </View>
            </View>
        );
    };

    YouTubeGetID(url) {
        url = url.split(/(vi\/|v=|\/v\/|youtu\.be\/|\/embed\/)/);
        return (url[2] !== undefined) ? url[2].split(/[^0-9a-z_\-]/i)[0] : url[0];
    }

    renderYouTube() {
        if (this.data.youtube != '') {
            return (
                <View style={{ marginTop: 20 }}>
                    <YoutubePlayer
                        height={300}
                        play={false}
                        videoId={this.YouTubeGetID(this.data.youtube)}
                        onChangeState={'play'}
                    />
                </View>
            )
        }
    }

    render() {
        const { activeSlide } = this.state;

        // const product = this.props.navigator.payloadForScreen?.[this.getScreenName()]?.product;



        const item = {
            name: "紫檀木《復刻》DIY 數碼相機",
            price: "1750",
            image: require("../../assets/images/145083538_105653554883958_5082731466280145478_o.png"),
            color: "Vintage",
            origin: "原質東隅",
        };

        return (
            <MenuProvider style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <TopBar self={this} />
                <TitleBar title={this.data.name} self={this} />
                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>

                    <View
                        style={{
                            width: width,
                            height: width,
                            marginTop: 10,
                        }}
                    >
                        <Carousel
                            data={
                                this.data.album
                            }
                            renderItem={this._renderItem}
                            onSnapToItem={(index) => this.setState({ activeSlide: index })}
                            windowSize={1}
                            layout={"default"}
                            sliderWidth={width}
                            itemWidth={width}
                            loop={true}
                            autoplay={true}
                            autoplayInterval={5000}
                            inactiveSlideScale={1}
                        />
                        <Pagination
                            dotsLength={
                                this.data.album.length
                            }
                            activeDotIndex={activeSlide}
                            containerStyle={{
                                paddingTop: 10,
                                paddingBottom: 10,
                            }}
                            dotStyle={{
                                width: 8,
                                height: 8,
                                borderRadius: 5,
                                marginHorizontal: 0,
                                backgroundColor: colors.BORDER_PINK,
                            }}
                            inactiveDotStyle={
                                {
                                    // Define styles for inactive dots here
                                }
                            }
                            inactiveDotOpacity={0.4}
                            inactiveDotScale={0.6}
                        />
                    </View>
                    <View style={{ width: width, paddingHorizontal: 20, marginTop: 10 }}>
                        <View >
                            <Text style={styles.home_product80938ed2} numberOfLines={2}>
                                {this.data.name}
                            </Text>

                            <Text style={styles.home_product80938ed3}>{this.store.category[this.store.category.findIndex(e => e.categoryId == this.data.categoryId)].name}</Text>
                            <Text style={styles.home_product80938ed2}>${this.data.price}</Text>
                            {/* <Image
                                source={images.ICON_SHARE}
                                style={{ width: 20, height: 20, resizeMode: "contain", position: "absolute", top: 0, right: 25 }}
                            /> */}
                            <View style={{ position: "absolute", top: 20, right: 0 }}>
                                {/* <FavouriteButton data={this.store.products[this.store.products.findIndex(e => e.productId == this.data.productId)]} /> */}
                            </View>

                        </View>



                        <View style={{ flexDirection: "row" }}>
                            <Menu
                                name="selectQty"
                                renderer={SlideInMenu}
                                onSelect={value => {
                                    this.store.changeQtyOnDetails(this.data.productId, value, this)
                                }}>
                                <MenuTrigger
                                    style={{
                                        width: 140,
                                        height: 30,
                                        marginTop: 10,
                                        borderColor: colors.BORDER_PINK,
                                        borderWidth: 1,
                                        borderRadius: 4,
                                        justifyContent: "center",
                                        alignItems: "center",
                                        backgroundColor: "white",
                                    }}
                                >
                                    <Text>{this.itemQtySelected}</Text>
                                    <Image
                                        source={images.ICON_ARROW_DOWN_OUTLINE}
                                        style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 7, right: 6 }}
                                    />
                                </MenuTrigger>
                                <MenuOptions
                                    customStyles={{
                                        optionText: {
                                            margin: 5,
                                            color: 'black',
                                            fontSize: 20,
                                        },
                                        optionWrapper: {
                                            // backgroundColor: colors.MAIN,
                                            alignItems: 'center',
                                        },
                                    }}>

                                    <FlatList
                                        data={this.itemQty}
                                        renderItem={({ item }) => (
                                            <MenuOption value={item} text={item} />
                                        )}
                                        style={{ height: 150 }}
                                    />
                                </MenuOptions>
                            </Menu>
                            <View style={{ flex: 1 }} />
                            <TouchableOpacity
                                onPress={() => { this.store.addShoppingCart(this.data.productId, this.itemQtySelected, this.itemOption, this) }}>
                                <View
                                    style={{
                                        width: 100,
                                        height: 30,
                                        marginTop: 10,
                                        borderRadius: 8,
                                        justifyContent: "center",
                                        alignItems: "center",
                                        backgroundColor: colors.BORDER_PINK,
                                    }}
                                >
                                    <Text style={{ color: "white" }}>{I18n.t('addToCart')}</Text>
                                </View>
                            </TouchableOpacity>
                        </View>
                        {this.data.productOptionsTitle != '' ? (
                            <View style={{ marginTop: 10 }}>
                                <Text style={{ fontWeight: '800' }}>
                                    {this.data.productOptionsTitle}
                                </Text>
                                <Menu
                                    name="options"
                                    renderer={SlideInMenu}
                                    onSelect={value => {
                                        this.store.changeOptionOnDetails(this.data.productId, value, this)
                                    }}>
                                    <MenuTrigger
                                        style={{
                                            width: 140,
                                            height: 30,
                                            marginTop: 10,
                                            borderColor: colors.BORDER_PINK,
                                            borderWidth: 1,
                                            borderRadius: 4,
                                            justifyContent: "center",
                                            alignItems: "center",
                                            backgroundColor: "white",
                                        }}
                                    >
                                        <Text>{this.itemOption == null ? '' : this.itemOption.name}</Text>
                                        <Image
                                            source={images.ICON_ARROW_DOWN_OUTLINE}
                                            style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 7, right: 6 }}
                                        />
                                    </MenuTrigger>
                                    <MenuOptions
                                        customStyles={{
                                            optionText: {
                                                margin: 5,
                                                color: 'black',
                                                fontSize: 20,
                                            },
                                            optionWrapper: {
                                                // backgroundColor: colors.MAIN,
                                                alignItems: 'center',
                                            },
                                        }}>

                                        <FlatList
                                            data={this.data.options}
                                            renderItem={({ item }) => (
                                                <MenuOption value={item} text={item.name} />
                                            )}
                                            style={{ height: 150 }}
                                        />
                                    </MenuOptions>
                                </Menu>
                            </View>) : (<View />)}


                        <View style={{ marginTop: 40 }}>
                            <Text style={{ fontSize: 18, fontWeight: "bold" }}>{I18n.t('productInformationAndNotes')}</Text>
                            {/* <Text style={{ marginTop: 20 }}>
                                {this.data.shortDescription}
                            </Text> */}
                            {
                                //youtube
                                this.renderYouTube()
                            }
                            <HTMLView
                                addLineBreaks={false}
                                value={this.data.shortDescription}
                                style={{ marginTop: 20 }}
                                stylesheet={{
                                    marginTop: 20,
                                    br: { marginTop: -20, },
                                    p: { marginTop: 0, }
                                }}
                            />

                            <HTMLView
                                addLineBreaks={false}
                                value={this.data.longDescription}
                                style={{ marginTop: 20 }}
                                stylesheet={{
                                    marginTop: 20,
                                    br: { marginTop: -20, },
                                    p: { marginTop: 0, }
                                }}
                            />

                        </View>
                        <Text
                            style={{
                                color: "rgba(39, 40, 51, 1)",
                                fontSize: 24,
                                fontWeight: "600",
                                fontStyle: "normal",
                                fontFamily: "Avenir",
                                marginTop: 40,
                            }}
                        >
                            {I18n.t("moreSimilarProducts")}
                        </Text>
                        <FlatList
                            style={{
                                height: 255,
                                marginTop: 20,
                                paddingBottom: 20,
                            }}
                            data={
                                // youMayLikeList
                                this.randomItem
                            }
                            horizontal={true}
                            keyExtractor={(item) => item?.name.toString()}
                            // onEndReachedThreshold={0.01}
                            // onEndReached={(info) => {
                            //   this.pageNum++;
                            //   this.getServerData(this.props, false);
                            // }}
                            ListHeaderComponent={() => {
                                return <View style={{ width: 0, height: "100%" }} />;
                            }}
                            renderItem={({ item, index, separators }) => {
                                if (index < 8) {
                                    return (
                                        <TouchableOpacity
                                            style={{ flex: 1 }}
                                            onPress={() => {
                                                this.store.goToProductDetails(item.productId, this);
                                            }}
                                        >
                                            <View
                                                style={{
                                                    height: "100%",
                                                    width: 141,
                                                    borderTopLeftRadius: 6,
                                                    borderTopRightRadius: 6,
                                                    borderBottomLeftRadius: 6,
                                                    borderBottomRightRadius: 6,
                                                }}
                                            >
                                                <FastImage
                                                    // source={{ uri: item?.images?.[0]?.src }}
                                                    source={{ uri: this.store.uriLink + item.image }}
                                                    style={{ width: 141, height: 141, resizeMode: "cover", borderColor: colors.BORDER_PINK, borderWidth: 1, borderRadius: 10 }}
                                                />
                                                <View
                                                    style={{
                                                        flex: 1,
                                                        justifyContent: "center",
                                                        // alignItems: "center",
                                                    }}
                                                >
                                                    <Text style={[styles.home_product80938ed2, { marginTop: 8, width: 140 }]} numberOfLines={1}>
                                                        {item?.name}
                                                    </Text>
                                                    <View style={{ flexDirection: 'row' }}>
                                                        <Text style={styles.home_product80938ed2}>${item?.price}</Text>
                                                        {/* <FavouriteButton data={item} /> */}
                                                    </View>
                                                </View>
                                            </View>
                                        </TouchableOpacity>
                                    );
                                }
                            }}
                            ItemSeparatorComponent={() => {
                                return <View style={{ width: 10, height: "100%" }} />;
                            }}
                            ListFooterComponent={() => {
                                return <View style={{ width: 23, height: "100%" }} />;
                            }}
                        />
                    </View>
                </ScrollView>
                <Toast
                    ref="toast"
                    style={{ backgroundColor: colors.BORDER_PINK }}
                    position="bottom"
                    positionValue={200}
                    fadeInDuration={750}
                    fadeOutDuration={2000}
                    opacity={0.8}
                    textStyle={{ color: 'white' }}
                />
            </MenuProvider>
        );
    }
}))


const styles = StyleSheet.create({
    home_product80938ed2: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 15,
        fontWeight: "bold",
        fontFamily: "Avenir",
        width: width / 1.3
    },
    home_product80938ed3: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 14,
        fontFamily: "Avenir",
    },
});



export default ProductsDetails
