import React, { Component } from "react";
import { Image as ReactImage, ScrollView, Text, View, TouchableOpacity, StyleSheet, TextInput, Linking } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import { width, height } from '../../services/screen'
import Toast, { DURATION } from 'react-native-easy-toast';
import { observable, makeObservable } from 'mobx'
import moment from 'moment'
import TopBar from '../../components/topBar'
import Loading from '../../components/Loading';
import { colors } from '../../assets/styles/colors-theme';
import I18n from '../../services/i18n'
import TitleBar from '../../components/titleBar'
import FastImage from "react-native-fast-image";
var _ = require('lodash');
const Redeem = inject("appStore")(observer(class Redeem extends React.Component {

    giftOrHistory = true
    constructor(props) {
        super(props);
        this.store = props.appStore;
        makeObservable(this, {
            giftOrHistory: observable
        });

    }

    componentDidMount() {
        this.store.getRedeemGift()
        this.store.getRedeemHistory()
    }

    redeemAction(item) {
        if (parseInt(this.store.userData.points) >= parseInt(item.pointNeed)) {
            this.store.redeem(item, this)
        } else {
            this.refs.toast.show(I18n.t('youNeedMoreCoinsToRedeemThisProduct'))
        }
    }
    renderHistoryList() {
        if (this.giftOrHistory) {
            return this.store.redeemGiftList.map((item, index) => {
                return (
                    <TouchableOpacity style={{ flex: 1, marginVertical: 30, marginHorizontal: 10, flexDirection: 'row' }}
                        onPress={() => this.redeemAction(item)}>
                        <View style={{ flex: 0.3, justifyContent: 'center', }}>
                            <FastImage
                                source={{ uri: this.store.uriLink + item.image }}
                                style={{
                                    width: 60,
                                    height: 60,
                                    marginRight: 5,
                                    resizeMode: "cover",
                                    borderColor: colors.BORDER_PINK,
                                    borderWidth: 1,
                                    borderRadius: 10,
                                }}
                            />
                        </View>
                        <View style={{ flex: 0.45, justifyContent: 'center', }}>
                            <Text>
                                {item.name}
                            </Text>
                        </View>
                        <View style={{ flex: 0.25, justifyContent: 'center', alignItems: 'center' }}>
                            <Text style={{ color: colors.BORDER_PINK }}>
                                {"Coins " + item.pointNeed}
                            </Text>
                        </View>

                    </TouchableOpacity>
                )
            })
        } else {
            return this.store.redeemHistory.map((item, index) => {
                return (
                    <TouchableOpacity style={{ flex: 1, marginVertical: 30, marginHorizontal: 10, flexDirection: 'row' }}
                        onPress={() => this.redeemAction(item)}>
                        <View style={{ flex: 0.3, justifyContent: 'center', }}>
                            <Text>
                                {item.date}
                            </Text>
                        </View>
                        <View style={{ flex: 0.45, justifyContent: 'center', }}>
                            <Text>
                                {this.store.lang == 'En' ? item.productNameEn : item.productNameTc}
                            </Text>
                        </View>
                        <View style={{ flex: 0.25, justifyContent: 'center', alignItems: 'center' }}>
                            <Text style={{ color: colors.BORDER_PINK }}>
                                {"Coins " + item.point}
                            </Text>
                        </View>

                    </TouchableOpacity>
                )
            })
        }
    }

    render() {

        const name = I18n.t('redeemGifts');

        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <Loading loading={this.store.loading} />
                <TopBar self={this} />
                <TitleBar title={name} self={this} />

                <View style={{ width: width, height: 50, flexDirection: 'row' }}>
                    <TouchableOpacity style={{ flex: 1, justifyContent: 'center', alignItems: 'center' }}
                        onPress={() => this.giftOrHistory = true}>
                        <Text style={{ color: this.giftOrHistory ? colors.BORDER_PINK : colors.maingray }}>
                            {I18n.t('redeemGifts')}
                        </Text>
                    </TouchableOpacity>
                    <TouchableOpacity style={{ flex: 1, justifyContent: 'center', alignItems: 'center' }}
                        onPress={() => this.giftOrHistory = false}>
                        <Text style={{ color: !this.giftOrHistory ? colors.BORDER_PINK : colors.maingray }}>
                            {I18n.t('redeemHistory')}
                        </Text>
                    </TouchableOpacity>
                </View>

                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>

                    {this.renderHistoryList()}

                </ScrollView>
                <Toast
                    ref="toast"
                    style={{ backgroundColor: colors.BORDER_PINK }}
                    position="center"
                    positionValue={200}
                    fadeInDuration={750}
                    fadeOutDuration={2000}
                    opacity={0.8}
                    textStyle={{ color: 'white' }}
                />
            </View>
        );
    }
}))


export default Redeem
