import React, { Component } from "react";
import { Image, ScrollView, Text, View, TouchableOpacity, StyleSheet } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import FastImage from 'react-native-fast-image'
import TopBar from '../../components/topBar'
import TitleBar from '../../components/titleBar'
import { colors } from '../../assets/styles/colors-theme';
import I18n from '../../services/i18n'
import FavouriteButton from '../../components/favouriteButton'

const Search = inject("appStore")(observer(class Search extends React.Component {

    itemList = []
    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {
            itemList: observable
        });
    }
    componentDidMount() {

        this._unsubscribe = this.props.navigation.addListener('focus', () => {
            this.favInit()
        });
    }


    componentWillUnmount() {
        this._unsubscribe();
    }
    favInit() {
        this.itemList = this.store.products.filter(e => e.favourite == true);
    }

    _renderCol(item) {
        const imageSrc = item ?.image;
        const name = item ?.name;

        return (
            <Col>
                {!!item && (
                    <TouchableOpacity
                        style={{
                            flex: 1,
                            paddingHorizontal: 10,
                        }}
                        onPress={() => {
                            this.store.goToProductDetails(item.productId, this);
                        }}
                    >
                        <FastImage
                            source={{ uri: this.store.uriLink + item.image }}
                            style={{
                                borderRadius: 10,
                                width: undefined,
                                height: 160,
                                resizeMode: "cover",
                                marginVertical: 10,
                                borderColor: colors.BORDER_PINK,
                                borderWidth: 1,
                            }}
                        />
                        <View
                            style={{
                                flex: 1,
                                justifyContent: "center",
                                // alignItems: "center",
                            }}
                        >
                            <Text style={styles.home_product80938ed2} numberOfLines={1}>
                                {name}
                            </Text>

                            <Text style={styles.home_product80938ed2}>${item ?.price}</Text>
                            {/* <FavouriteButton data={item} self={this} fav={true} /> */}
                        </View>
                    </TouchableOpacity>
                )}
            </Col>
        );
    }

    renderItemList() {

        return this.store.searchResult.map((item, index, array) => {

            const newRow = !(index % 2);
            const secondItem = index + 1 < array.length ? array[index + 1] : undefined;

            const id = item.name;
            return (
                <Row key={id} style={{ paddingHorizontal: 10 }}>
                    {!!newRow ? (
                        <>
                            {this._renderCol(item)}
                            {this._renderCol(secondItem)}
                        </>
                    ) : null}
                </Row>
            );

        })
    }

    render() {

        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <TopBar self={this} />
                <TitleBar title={I18n.t('searchResult')} self={this} />

                {this.store.searchResult.length > 0 ? (<ScrollView ref="_scrollView" nestedScrollEnabled={true} style={{ marginHorizontal: 0 }}>

                    <View style={{ flex: 1, alignItems: "center" }}>

                        <Grid
                            style={{
                                width: "100%",
                                paddingBottom: 20,
                            }}
                        >
                            {
                                // productList
                                this.renderItemList()
                            }
                        </Grid>
                    </View>
                </ScrollView>) : (<View style={{ flex: 1, marginTop: 80, alignItems: 'center' }}>
                    {/* <Image
                        source={images.ICON_HEART}
                        style={{
                            height: 140,
                            resizeMode: "contain",

                        }}
                    /> */}
                    <Text style={{ fontSize: 18, marginTop: 40 }}>{I18n.t('searchResult0')}</Text>
                    {/* <Text style={{ fontSize: 18, marginTop: 5 }}>{"左上返回繼續購物吧！"}</Text> */}
                </View>)}
            </View>
        );
    }
}))

const styles = StyleSheet.create({
    home_product80938ed2: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 13,
        fontWeight: "bold",
        fontFamily: "Avenir",
    },
    home_product80938ed3: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 12,
        fontFamily: "Avenir",
    },
});



export default Search
