import React, { Component } from "react";
import { Image as ReactImage, ScrollView, Text, View, TouchableOpacity, StyleSheet, TextInput } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import Toast, { DURATION } from 'react-native-easy-toast';
import { observable, makeObservable } from 'mobx'
import TopBar from '../../components/topBar'
import { colors } from '../../assets/styles/colors-theme';
import I18n from '../../services/i18n'
import TitleBar from '../../components/titleBar'

const Profile = inject("appStore")(observer(class Profile extends React.Component {
    getScreenName() {
        return "profile";
    }

    nameModify = false
    newName = ''

    constructor(props) {
        super(props);
        this.store = props.appStore;
        makeObservable(this, {
            nameModify: observable,
            newName: observable
        });

    }


    modifyNameAction() {
        if (this.newName != '') {
            if (this.newName.length <= 20) {
                this.store.updateMember(this.newName, this)
            } else {
                this.refs.toast.show("Too many charaters")
            }
        } else {
            this.refs.toast.show("Can't empty")
        }
    }

    render() {


        // const product = this.props.navigator.payloadForScreen?.[this.getScreenName()]?.product;

        const name = I18n.t('accountDetails');

        return (
            <View style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <TopBar self={this} />
                <TitleBar title={name} self={this} />
                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>

                    <View style={{ marginHorizontal: 40, marginTop: 20 }}>
                        {
                            this.nameModify ? (<TextInput
                                style={{
                                    width: "50%",
                                    height: 22,
                                    borderColor: colors.BORDER_PINK,
                                    borderWidth: 1,
                                    borderRadius: 4,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: "white",
                                    fontSize: 12,
                                    marginBottom: Platform.OS === 'ios' ? 3 : 0,
                                    paddingVertical: 0,
                                    paddingHorizontal: 7,
                                }}
                                value={this.newName}
                                onChangeText={text => this.newName = text}
                                placeholder={I18n.t('pleaseInputYourName')}
                            />) : (<Text style={{}}>{I18n.t("userName") + ": " + this.store.userData.name}</Text>)
                        }

                        <Text style={{ marginTop: 10 }}>{I18n.t("userId") + ": " + this.store.userData.memberId}</Text>
                        <Text style={{ marginTop: 10 }}>{I18n.t("loginEmail") + ": " + this.store.userData.email}</Text>
                        {/* <Text style={{ marginTop: 10 }}>聯絡電話: 9123 4567</Text> */}

                        <TouchableOpacity
                            style={{ position: "absolute", right: 0, top: -2 }}
                            onPress={() => {
                                if (this.nameModify) {
                                    this.modifyNameAction()
                                } else {
                                    this.nameModify = true
                                }
                            }}
                        >
                            <View
                                style={{
                                    width: 50,
                                    height: 25,
                                    borderRadius: 8,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: colors.BORDER_PINK,
                                }}
                            >
                                <Text style={{ color: "white", fontSize: 14 }}>{I18n.t('modify')}</Text>
                            </View>
                        </TouchableOpacity>
                        {/* <View style={{ borderTopColor: "black", borderTopWidth: 1, marginVertical: 30 }} /> */}
                    </View>
                    {/* <View style={{ marginHorizontal: 40 }}>
                        <Text style={{}}>已儲存送貨地址:</Text>
                        <Text style={{ marginTop: 10 }}>地址 1:</Text>
                        <Text style={{ marginTop: 5 }}>葵涌華星街8號華達工業中心B座1216室</Text>
                        <Text style={{ marginTop: 10 }}>地址 2:</Text>
                        <Text style={{ marginTop: 5 }}>葵涌華星街8號華達工業中心B座1216室</Text>
                        <TouchableOpacity
                            style={{ position: "absolute", right: 0, top: 0 }}
                            onPress={() => {
                                this.props.navigateTo({ screen: "registrationCompleted" });
                            }}
                        >
                            <View
                                style={{
                                    width: 50,
                                    height: 25,
                                    borderRadius: 8,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: colors.BORDER_PINK,
                                }}
                            >
                                <Text style={{ color: "white", fontSize: 14 }}>更改</Text>
                            </View>
                        </TouchableOpacity>
                    </View> */}
                </ScrollView>
                <Toast
                    ref="toast"
                    style={{ backgroundColor: colors.BORDER_PINK }}
                    position="center"
                    positionValue={200}
                    fadeInDuration={750}
                    fadeOutDuration={2000}
                    opacity={0.8}
                    textStyle={{ color: 'white' }}
                />
            </View>
        );
    }
}))


export default Profile
