import React, { Component } from "react";
import { Image, ScrollView, StyleSheet, Text, View, TouchableOpacity, TextInput, Linking, Alert } from "react-native";
import { Col, Grid, Row } from "react-native-easy-grid";
import { images } from "../../assets/images/index";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import TitleBar from '../../components/titleBar'
import TopBar from '../../components/topBar'
import Loading from '../../components/Loading';
import { colors } from '../../assets/styles/colors-theme';
import Icon from 'react-native-vector-icons/dist/MaterialCommunityIcons'
import I18n from '../../services/i18n'
import Menu, {
    MenuProvider,
    MenuTrigger,
    MenuOptions,
    MenuOption,
    renderers,
} from 'react-native-popup-menu';
const { SlideInMenu } = renderers;
const Setting = inject("appStore")(observer(class Setting extends React.Component {



    constructor(props) {
        super(props);
        this.store = props.appStore;
        makeObservable(this, {

        });

    }

    langLabelHandler() {
        if (this.store.lang == 'Tc') {
            return '繁'
        } else if (this.store.lang == 'En') {
            return 'Eng'
        }
    }

    changeLang(value) {
        if (value == 'Tc') {
            I18n.locale = "zh_hk";
            this.store.lang = value
        } else if (value == 'En') {
            I18n.locale = "en";
            this.store.lang = value
        }
        this.store.changeLanguage(value)
    }
    linkAction(which) {
        switch (which) {
            case 0:
                Linking.openURL(
                    "https://annchoi.com/yeanaan/termsandconditions"
                );
                break;
            case 1:
                Linking.openURL(
                    "https://annchoi.com/yeanaan/lulu"
                );
                break;
            case 2:
                Linking.openURL(
                    "https://annchoi.com/yeanaan/contact-us"
                );
                break;
            case 3:
                // Linking.openURL(
                //     "https://annchoi.com/yeanaan/faq"
                // );
                this.props.navigation.navigate('OrderConfirmed')
                break;
        }
    }

    async deleteAcAction() {
        Alert.alert(
            I18n.t('deleteAccount'),
            I18n.t('deleteinfo'),
            [
                {
                    text: "Cancel",
                    onPress: () => console.log("Cancel Pressed"),
                    style: "cancel"
                },
                {
                    text: "OK", onPress: async () => {
                        await this.props.navigation.navigate('Main')
                        this.store.userData = null;
                        this.store.logined = false;
                    }
                }
            ]
        );
    }


    render() {

        const name = I18n.t("myAccount");

        return (
            <MenuProvider style={{ flex: 1, backgroundColor: colors.MAIN }}>
                <Loading loading={this.store.loading} />
                <TopBar self={this} />
                <TitleBar title={name} hideBack={true} bold={true} />
                <ScrollView ref="_scrollView" nestedScrollEnabled={true}>

                    <View style={{ marginHorizontal: 40 }}>
                        <View style={{ flex: 1, alignItems: "center" }}>
                            <Text style={{ fontSize: 20, marginTop: 10 }}>{"Welcome!"}</Text>
                            <Text style={{ fontSize: 16, marginTop: 5 }}>{this.store.userData != null ? this.store.userData.name : ''}</Text>
                            <Text style={{ fontSize: 16, marginTop: 5 }}>{this.store.userData != null ? "My Coins: " + this.store.userData.points : ''}</Text>
                        </View>
                        <View style={{ borderTopColor: "black", borderTopWidth: 1, marginVertical: 20 }} />
                        <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center" }}>
                            <Image source={images.ICON.PROFILE} style={{ width: 15, height: 15, resizeMode: "contain" }} />
                            <TouchableOpacity
                                onPress={() => {
                                    this.props.navigation.navigate('Profile')
                                }}
                            >
                                <Text style={{ width: 120, textAlign: "center" }}>{I18n.t('accountDetails')}</Text>
                            </TouchableOpacity>
                        </View>
                        {/* <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 20 }}>
                            <Image source={images.ICON.CREDIT_CARD} style={{ width: 15, height: 15, resizeMode: "contain" }} />
                            <TouchableOpacity
                                onPress={() => {
                                    this.props.navigation.navigate('MyWallet')
                                }}
                            >
                                <Text style={{ width: 120, textAlign: "center" }}>我的錢包</Text>
                            </TouchableOpacity>
                        </View> */}
                        <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 20 }}>
                            <Image source={images.ICON.ORDER} style={{ width: 15, height: 15, resizeMode: "contain" }} />
                            <TouchableOpacity
                                onPress={() => {
                                    this.props.navigation.navigate('HistoryList')
                                }}
                            >
                                <Text style={{ width: 120, textAlign: "center" }}>{I18n.t('orderRecord')}</Text>
                            </TouchableOpacity>
                        </View>
                        <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 20 }}>
                            <Icon name={'gift'} size={15} />
                            <TouchableOpacity
                                onPress={() => {
                                    this.props.navigation.navigate('Redeem')
                                }}
                            >
                                <Text style={{ width: 120, textAlign: "center" }}>{I18n.t('redeemGifts')}</Text>
                            </TouchableOpacity>
                        </View>
                        <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 20 }}>
                            <Image source={images.ICON.LOGOUT} style={{ width: 15, height: 15, resizeMode: "contain" }} />
                            <TouchableOpacity
                                onPress={async () => {this.deleteAcAction()}}
                            >
                                <Text style={{ width: 120, textAlign: "center" }}>{I18n.t('deleteAccount')}</Text>
                            </TouchableOpacity>
                        </View>
                        <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 20 }}>
                            <Icon name={'delete'} size={15} />
                            <TouchableOpacity
                                onPress={async () => {
                                    await this.props.navigation.navigate('Main')
                                    this.store.userData = null;
                                    this.store.logined = false;
                                }}
                            >
                                <Text style={{ width: 120, textAlign: "center" }}>{I18n.t('settingsLogout')}</Text>
                            </TouchableOpacity>
                        </View>
                        <View style={{ borderTopColor: "black", borderTopWidth: 1, marginVertical: 20 }} />
                        <TouchableOpacity style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 10 }}
                            onPress={() => { this.linkAction(0) }}>
                            <Text style={{}}>{I18n.t('termsAndConditions')}</Text>
                        </TouchableOpacity>

                        <TouchableOpacity style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 10 }}
                            onPress={() => { this.linkAction(2) }}>
                            <Text style={{}}>{I18n.t('contactUs')}</Text>
                        </TouchableOpacity>
                        <TouchableOpacity style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 10 }}
                            onPress={() => { this.linkAction(3) }}>
                            <Text style={{}}>{I18n.t('faq')}</Text>
                        </TouchableOpacity>
                        <TouchableOpacity style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 10 }}
                            onPress={() => { this.linkAction(1) }}>
                            <Text style={{}}>{I18n.t('aboutLuLu')}</Text>
                        </TouchableOpacity>
                        <View style={{ flexDirection: "row", justifyContent: "center", alignItems: "center", marginTop: 20 }}>
                            <Text>{I18n.t('settingsLanguage')}</Text>
                            <Menu
                                name="selectLang"
                                renderer={SlideInMenu}
                                onSelect={value => {
                                    this.changeLang(value)
                                }}>
                                <MenuTrigger
                                    style={{
                                        marginLeft: 10,
                                        width: 70,
                                        height: 25,
                                        borderColor: colors.BORDER_PINK,
                                        borderWidth: 1,
                                        borderRadius: 4,
                                        justifyContent: "center",
                                        alignItems: "center",
                                        backgroundColor: "white",
                                    }}
                                >
                                    <Text style={{ fontSize: 13, marginRight: 5 }}>{this.langLabelHandler()}</Text>
                                    <Image
                                        source={images.ICON_ARROW_DOWN_OUTLINE}
                                        style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 5, right: 6 }}
                                    />
                                </MenuTrigger>
                                <MenuOptions
                                    customStyles={{
                                        optionText: {
                                            margin: 5,
                                            color: 'black',
                                            fontSize: 20,
                                        },
                                        optionWrapper: {
                                            // backgroundColor: colors.MAIN,
                                            alignItems: 'center',
                                        },
                                    }}>

                                    <MenuOption value={'Tc'} text={'繁'} />
                                    <MenuOption value={'En'} text={'英'} />
                                </MenuOptions>
                            </Menu>
                        </View>
                    </View>
                </ScrollView>
            </MenuProvider>
        );
    }
}))

const styles = StyleSheet.create({
    home_product80938ed2: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 13,
        fontWeight: "bold",
        fontFamily: "Avenir",
    },
    home_product80938ed3: {
        color: "rgba(39, 40, 51, 1)",
        fontSize: 12,
        fontFamily: "Avenir",
    },
});



export default Setting