import React, { Component } from "react";
import { Image, ScrollView, Text, View, TouchableOpacity, TextInput, StyleSheet, FlatList, Platform } from "react-native";
import CheckBox from "@react-native-community/checkbox";
import { inject, observer } from "mobx-react"
import { observable, makeObservable } from 'mobx'
import { KeyboardAwareScrollView } from 'react-native-keyboard-aware-scroll-view';
import { colors } from '../../assets/styles/colors-theme';
import Toast, { DURATION } from 'react-native-easy-toast';
import Loading from '../../components/Loading';
import { width, height } from '../../services/screen'
import TopBar from '../../components/topBar'
import { images } from "../../assets/images/index";
import I18n from '../../services/i18n'
import TitleBar from '../../components/titleBar'
import Menu, {
    MenuProvider,
    MenuTrigger,
    MenuOptions,
    MenuOption,
    renderers,
} from 'react-native-popup-menu';
const { SlideInMenu } = renderers;
const gender = ['M', 'F']
const Signup = inject("appStore")(observer(class Signup extends React.Component {
    month = [];
    day = [];
    memberData = {
        name: '',
        email: '',
        password: '',
    };
    confirmPassword = ''
    checked = false

    constructor(props) {
        super(props);
        this.store = props.appStore
        makeObservable(this, {
            checked: observable,
            memberData: observable,
            confirmPassword: observable
        });
        for (var i = 1; i <= 31; i++) {
            this.day.push(i)
        }
        for (var d = 1; d <= 12; d++) {
            this.month.push(d)
        }
    }

    signupAction() {
        if (this.memberData.name != '') {
            if (this.memberData.email != '') {
                if (this.memberData.password != '') {
                    if (this.memberData.password.length >= 8) {
                        if (this.memberData.password === this.confirmPassword) {
                            this.store.signupPost(this.memberData, this)
                        } else {
                            this.refs.toast.show(I18n.t('thePasswordDoesNotMatchTheConfirmedPassword'))
                        }
                    } else {
                        this.refs.toast.show(I18n.t('yourPasswordMustBeAtLeast8Characters'))
                    }
                } else {
                    this.refs.toast.show(I18n.t('pleaseInputYourPassword'))
                }
            } else {
                this.refs.toast.show(I18n.t('pleaseInputYourEmailAddress'))
            }
        } else {
            this.refs.toast.show(I18n.t('pleaseInputYourName'))
        }
    }


    onShowing({ nextProps }) { }

    render() {

        // const product = this.props.navigator.payloadForScreen?.[this.getScreenName()]?.product;

        const name = I18n.t("signUpAccount");


        return (
            <MenuProvider style={{
                flex: 1, backgroundColor: colors.MAIN
            }}>
                <Loading loading={this.store.loading} />
                <TopBar self={this} />
                <TitleBar title={name} self={this} />
                <KeyboardAwareScrollView
                    keyboardShouldPersistTaps={"handled"}
                    enableResetScrollToCoords={false} nestedScrollEnabled={true}>
                    <View style={{ marginHorizontal: 40 }}>
                        <View style={{ marginTop: 20 }}>
                            <Text style={{ fontSize: 14 }}>{I18n.t('settingsName') + "*"}</Text>
                            <TextInput
                                style={styles.inputStyle}
                                placeholder={I18n.t("pleaseInputYourName")}
                                value={this.memberData.name}
                                onChangeText={text => this.memberData.name = text}
                            />
                        </View>
                        {/* <View style={{ marginTop: 10 }}>
                            <View style={{ flexDirection: "row", alignItems: "flex-end" }}>
                                <Text style={{ fontSize: 14 }}>聯絡電話*</Text>
                                <Text style={{ fontSize: 10, marginBottom: 2, marginLeft: 15 }}>(將會用作登入之用)</Text>
                            </View>
                            <TextInput
                                style={styles.inputStyle}
                                placeholder={"請輸入您的聯絡電話"}
                            />
                        </View> */}
                        <View style={{ marginTop: 10 }}>
                            <View style={{ flexDirection: "row", alignItems: "flex-end" }}>
                                <Text style={{ fontSize: 14 }}>{I18n.t('loginEmail') + "*"}</Text>
                                {/* <Text style={{ fontSize: 10, marginBottom: 2, marginLeft: 15 }}>(將會用作登入之用)</Text> */}
                            </View>
                            <TextInput
                                style={styles.inputStyle}
                                placeholder={I18n.t('pleaseInputYourEmailAddress')}
                                value={this.memberData.email}
                                onChangeText={text => this.memberData.email = text}
                            />
                        </View>
                        <View style={{ marginTop: 10 }}>
                            <Text style={{ fontSize: 14 }}>{I18n.t('loginPassword') + "*"}</Text>
                            <TextInput
                                style={styles.inputStyle}
                                placeholder={I18n.t("pleaseInputYourPassword")}
                                value={this.memberData.password}
                                onChangeText={text => this.memberData.password = text}
                                secureTextEntry={true}
                            />
                        </View>
                        <View style={{ marginTop: 10 }}>
                            <Text style={{ fontSize: 14 }}>{I18n.t('registrationConfirmPassword') + "*"}</Text>
                            <TextInput
                                style={styles.inputStyle}
                                placeholder={I18n.t('pleaseEnterConfirmPassword')}
                                value={this.confirmPassword}
                                onChangeText={text => this.confirmPassword = text}
                                secureTextEntry={true}
                            />
                        </View>
                        {/* <View style={{ marginTop: 10 }}>
                            <Text style={{ fontSize: 14 }}>性別</Text>
                            <Menu
                                name="selectGender"
                                renderer={SlideInMenu}
                                onSelect={value => {
                                    this.memberData.gender = value
                                }}>
                                <MenuTrigger
                                    style={styles.SelectBoxStyle}>
                                    <Text style={{ fontSize: 13, marginRight: 5 }}>{this.memberData.gender}</Text>
                                    <Image
                                        source={images.ICON_ARROW_DOWN_OUTLINE}
                                        style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 5, right: 6 }}
                                    />
                                </MenuTrigger>
                                <MenuOptions
                                    customStyles={{
                                        optionText: {
                                            margin: 5,
                                            color: 'black',
                                            fontSize: 20,
                                        },
                                        optionWrapper: {
                                            // backgroundColor: colors.MAIN,
                                            alignItems: 'center',
                                        },
                                    }}>

                                    <FlatList
                                        data={gender}
                                        renderItem={({ item }) => (
                                            <MenuOption value={item} text={item} />
                                        )}
                                        style={{ height: 120 }}
                                    />
                                </MenuOptions>
                            </Menu>
                        </View>
                        <View style={{ marginTop: 10 }}>
                            <Text style={{ fontSize: 14 }}>生日</Text>
                            <View style={{ flexDirection: "row" }}>
                                <Menu
                                    name="monthGender"
                                    renderer={SlideInMenu}
                                    onSelect={value => {
                                        this.memberData.month = value
                                    }}>
                                    <MenuTrigger
                                        style={styles.SelectBoxStyle}>

                                        <Text style={{ fontSize: 13, color: "gray", marginRight: 5 }}>{this.memberData.month}</Text>
                                        <Image
                                            source={images.ICON_ARROW_DOWN_OUTLINE}
                                            style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 5, right: 6 }}
                                        />

                                    </MenuTrigger>
                                    <MenuOptions
                                        customStyles={{
                                            optionText: {
                                                margin: 5,
                                                color: 'black',
                                                fontSize: 20,
                                            },
                                            optionWrapper: {
                                                // backgroundColor: colors.MAIN,
                                                alignItems: 'center',
                                            },
                                        }}>

                                        <FlatList
                                            data={this.month}
                                            renderItem={({ item }) => (
                                                <MenuOption value={item} text={item} />
                                            )}
                                            style={{ height: 120 }}
                                        />
                                    </MenuOptions>
                                </Menu>

                                <View style={{ marginLeft: 20 }}>
                                    <Menu
                                        name="dayGender"
                                        renderer={SlideInMenu}
                                        onSelect={value => {
                                            this.memberData.day = value
                                        }}>
                                        <MenuTrigger
                                            style={styles.SelectBoxStyle}
                                        >
                                            <Text style={{ fontSize: 13, color: "gray", marginRight: 5 }}>{this.memberData.day}</Text>
                                            <Image
                                                source={images.ICON_ARROW_DOWN_OUTLINE}
                                                style={{ width: 15, height: 15, resizeMode: "contain", position: "absolute", top: 5, right: 6 }}
                                            />
                                        </MenuTrigger>
                                        <MenuOptions
                                            customStyles={{
                                                optionText: {
                                                    margin: 5,
                                                    color: 'black',
                                                    fontSize: 20,
                                                },
                                                optionWrapper: {
                                                    // backgroundColor: colors.MAIN,
                                                    alignItems: 'center',
                                                },
                                            }}>

                                            <FlatList
                                                data={this.day}
                                                renderItem={({ item }) => (
                                                    <MenuOption value={item} text={item} />
                                                )}
                                                style={{ height: 120 }}
                                            />
                                        </MenuOptions>

                                    </Menu>
                                </View>
                            </View>
                        </View> */}
                        {/* <View style={{ flexDirection: "row", marginTop: 20, alignItems: 'center', }}>
                            <CheckBox
                                //  tintColor={colors.BORDER_PINK}
                                onCheckColor={colors.BORDER_PINK}
                                onTintColor={colors.BORDER_PINK}
                                // onFillColor={colors.BORDER_PINK}
                                //boxType={'square'}
                                style={{ width: 14, height: 14, }}
                                disabled={false}
                                value={this.checked}
                                onValueChange={(value) => { this.checked = value }}
                            />
                            <View>
                                <Text style={{ marginTop: 2, marginLeft: 10 }}>{"*我已閱讀並同意 私隱政策"}</Text>
                            </View>
                        </View> */}
                        <TouchableOpacity
                            onPress={() => {
                                // this.props.navigation.replace('SignupSuccess')
                                this.signupAction()
                            }}
                        >
                            <View
                                style={{
                                    width: "100%",
                                    height: 40,
                                    marginVertical: 30,
                                    borderRadius: 8,
                                    justifyContent: "center",
                                    alignItems: "center",
                                    backgroundColor: colors.BORDER_PINK,
                                }}
                            >
                                <Text style={{ color: "white" }}>{I18n.t("loginRegistration")}</Text>
                            </View>
                        </TouchableOpacity>
                    </View>
                    <Toast
                        ref="toast"
                        style={{ backgroundColor: colors.BORDER_PINK }}
                        position="center"
                        positionValue={200}
                        fadeInDuration={750}
                        fadeOutDuration={2000}
                        opacity={0.8}
                        textStyle={{ color: 'white' }}
                    />
                </KeyboardAwareScrollView>
            </MenuProvider >
        );
    }
}))

const styles = StyleSheet.create({
    SelectBoxStyle: {
        width: 70,
        height: 25,
        marginTop: 5,
        borderColor: colors.BORDER_PINK,
        borderWidth: 1,
        borderRadius: 4,
        justifyContent: "center",
        alignItems: "center",
        backgroundColor: "white",
    },
    inputStyle: {
        width: "100%",
        height: 35,
        marginTop: 5,
        borderColor: colors.BORDER_PINK,
        borderWidth: 1,
        borderRadius: 4,
        justifyContent: "center",
        alignItems: "center",
        backgroundColor: "white",
        fontSize: 12,
        paddingHorizontal: 7,
        marginBottom: Platform.OS === 'ios' ? 3 : 0,
        paddingVertical: 0,
    }
})

export default Signup