
import { makeAutoObservable, action, observable } from "mobx";
import api from '../services/api';
import axios from 'axios';
import { Alert } from "react-native";
import I18n from '../services/i18n'
import moment from 'moment'
import uuid from 'react-native-uuid';
import AsyncStorage from '@react-native-community/async-storage';
var _ = require('lodash');
const showLog = true

class Stores {
  uriLink = 'https://annchoi.com/'
  routerState
  test = 'Testing'
  loading = false
  banner = []
  category = []
  products = []
  shoppingCart = []
  searchResult = []
  history = []
  favouriteProducts = []
  coupons = []
  giftList = []
  redeemHistory = []
  couponData = null
  coupon = ''
  splash = false;
  logined = false;
  lang = 'Tc';
  userData = null
  uploadImage = null
  paymentData = {
    orderId: '',
    shipping: {
      name: "",
      phone: "",
      email: "",
      address: "",
      delivery: 2
    }
  }


  // `this` from rootstore passed to the constructor and we can 
  // assign it to a variable accessible in this class called 
  // `rootStore`. Therefore, we can access other store like 
  // useStore for e.g (this.rootStore.userStore)
  constructor(rootStore) {
    makeAutoObservable(this, {
      history: observable,
      routerState: observable,
      loading: observable,
      giftList: observable,
      test: observable,
      banner: observable,
      splash: observable,
      logined: observable,
      lang: observable,
      redeemHistory: observable,
      products: observable,
      userData: observable,
      favouriteProducts: observable,
      searchResult: observable,
      shoppingCart: observable,
      couponData: observable,
      coupon: observable,
      uploadImage: observable,
      paymentData: observable,
      log: action,
      setRouterRef: action,
      setRouterState: action,
      getBanner: action,
      getCategory: action,
    });

  }

  async appInit() {
    await this.getBanner();
    await this.getCategory();
    await this.getProductsList('', 'all', '0');
    this.getCoupons()
    this.getRedeemGift()
  }

  changeLanguage(value) {
    try {
      AsyncStorage.setItem('lang', value)
      this.appInit()
    } catch (e) {
      console.info(e)
    }
  }

  idGenerator() {
    return uuid.v4();
  }

  async getRedeemHistory() {
    this.redeemHistory = []
    var url = api.redeemHistory
    const data = {}
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      console.info(response);
      this.redeemHistory = response.data
      // this.redeemGiftList = response.data.carts
    } catch (error) {
      console.info(error.response);
    }
  }

  async redeem(item, self) {
    this.loading = true
    var url = api.redeem;
    var data = {
      productId: item.productId
    }
    try {
      const response = await axios.post(url, data, {
        headers: {
          'Content-Type': 'application/json',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      console.info(data.pointNeed)
      if (response.data.code == 200) {
        self.refs.toast.show(I18n.t('redeemSuccessed'))
        this.userData.points = parseInt(this.userData.points) - parseInt(item.pointNeed)
        this.getRedeemHistory()
      }
    } catch (error) {
      this.loading = false;
      this.log(error.response);
      self.refs.toast.show(error.response.data.msg)
    }
  }

  async getRedeemGift() {
    this.redeemGiftList = []
    var url = api.redeemGiftList + "?lang=" + this.lang;
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      console.info(response);
      this.redeemGiftList = response.data
      // this.redeemGiftList = response.data.carts
    } catch (error) {
      console.info(error.response);
    }
  }

  async getHistory() {
    this.history = []
    var url = api.allCart;
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.log(response);
      this.history = response.data.carts
    } catch (error) {
      this.log(error);
    }
  }

  async payByOther(self) {
    this.loading = true
    var url = api.payByOther;
    const date = moment().format('DDMMYYYYssmmhh');
    var data = _.cloneDeep(this.paymentData)
    const fileData = new FormData();
    fileData.append('image', {
      uri: this.uploadImage.uri,
      name: 'bank' + date + '.png',
      type: 'image/png',
    });
    fileData.append('orderId', data.orderId);
    fileData.append('name', data.shipping.name);
    fileData.append('phone', data.shipping.phone);
    fileData.append('email', data.shipping.email);
    fileData.append('address', data.shipping.address);
    fileData.append('delivery', data.shipping.delivery);
    try {
      const response = await axios.post(url, fileData, {
        headers: {
          'Content-Type': 'multipart/form-data',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      await this.finishPayment()
      await self.props.navigation.popToTop()
      self.props.navigation.navigate('OrderConfirmed')
    } catch (error) {
      this.loading = false;
      this.log(error.response);
      // self.refs.toast.show(error.response.data.msg)
    }
  }


  async payByPalPal(self) {
    this.loading = true
    var url = api.payByPalPal;
    var data = _.cloneDeep(this.paymentData)
    try {
      const response = await axios.put(url, data, {
        headers: {
          'Content-Type': 'application/json',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      if (response.data.hasOwnProperty('checkoutUrl')) {
        await self.props.navigation.popToTop()
        response.data.checkoutUrl = response.data.checkoutUrl + '?lang=' + this.lang + "&orderId=" + data.orderId + "&token=" + this.userData.token
        response.data.success_url = await response.data.success_url.replace('.php', '');
        response.data.fail_url = await response.data.fail_url.replace('.php', '');
        response.data.cancel_url = await response.data.cancel_url.replace('.php', '');
        console.info(response.data)
        self.props.navigation.navigate('StripePayment', { data: response.data, which: true })
      }


    } catch (error) {
      this.loading = false;
      this.log(error.response);
      // self.refs.toast.show(error.response.data.msg)
    }
  }


  async payByStripe(self) {
    this.loading = true
    var url = api.payByStripe;
    var data = _.cloneDeep(this.paymentData)
    try {
      const response = await axios.put(url, data, {
        headers: {
          'Content-Type': 'application/json',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      if (response.data.hasOwnProperty('checkoutUrl')) {
        await self.props.navigation.popToTop()
        self.props.navigation.navigate('StripePayment', { data: response.data, which: false })
      }


    } catch (error) {
      this.loading = false;
      this.log(error.response);
      // self.refs.toast.show(error.response.data.msg)
    }
  }

  async payByCash(self) {
    this.loading = true
    var url = api.payByCash;
    var data = _.cloneDeep(this.paymentData)
    try {
      const response = await axios.put(url, data, {
        headers: {
          'Content-Type': 'application/json',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      await this.finishPayment()
      await self.props.navigation.popToTop()
      self.props.navigation.navigate('OrderConfirmed')

    } catch (error) {
      this.loading = false;
      this.log(error.response);
      // self.refs.toast.show(error.response.data.msg)
    }
  }

  async finishPayment() {
    this.paymentData = {
      orderId: '',
      shipping: {
        name: "",
        phone: "",
        email: "",
        address: "",
        delivery: 2
      }
    }
    this.uploadImage = null
    try {
      await AsyncStorage.removeItem('shoppingCart')
    } catch (e) {
      // remove error
    }
    this.shoppingCart = []
    this.couponData = null
    this.coupon = ''
  }

  async order(data, orderData, self) {
    this.loading = true
    var url = api.order;
    console.info(this.userData.token)
    try {
      const response = await axios.put(url, data, {
        headers: {
          'Content-Type': 'application/json',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      if (response.data.hasOwnProperty('cartId')) {
        this.paymentData.orderId = response.data.cartId
        self.props.navigation.navigate('Shipping', { orderData: orderData })
      }
    } catch (error) {
      this.loading = false;
      this.log(error.response);
      // self.refs.toast.show(error.response.data.msg)
    }
  }

  async updateMember(name, self) {
    console.log(this.userData.token)
    this.loading = true
    var url = api.updateMember;
    var data = { name: name }
    try {
      const response = await axios.post(url, data, {
        headers: {
          'Content-Type': 'application/json',
          'token': this.userData.token,
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      this.userData.name = name;
      self.newName = ''
      self.nameModify = false
    } catch (error) {
      this.loading = false;
      this.log(error.response);
      self.refs.toast.show(error.response.data.msg)
    }
  }

  async getCoupons() {
    this.coupons = []
    var url = api.coupons;
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
        },
        timeout: 20000,
      });
      this.loading = false
      this.log(response);
      response.data.map((item, index) => {

        this.coupons.push(item)

      })
    } catch (error) {

      this.log(error);
    }
  }
  async forgotPassword(email, self) {
    this.loading = true
    var url = api.forgotPassword;
    var data = {}
    try {
      const response = await axios.post(url, data, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
          email: email,
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      Alert.alert(
        '',
        I18n.t('forgotEmailSuccess'),
        [

          { text: 'OK', onPress: () => self.props.navigation.goBack() },
        ],
        { cancelable: false },
      );
    } catch (error) {
      this.loading = false;
      this.log(error.response);
      self.refs.toast.show(error.response.data.msg)
    }
  }
  async signupPost(signupData, self) {
    console.info(signupData)
    this.loading = true
    var url = api.signup;
    var data = {}
    try {
      const response = await axios.post(url, data, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
          name: signupData.name,
          email: signupData.email,
          password: signupData.password
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)


      self.props.navigation.replace('SignupSuccess')
    } catch (error) {
      this.loading = false;
      this.log(error.response);
      self.refs.toast.show(error.response.data.msg)
    }
  }

  async loginPost(loginData, self) {
    this.loading = true
    var url = api.login;
    var data = {}
    try {
      const response = await axios.post(url, data, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
          email: loginData.email,
          password: loginData.password
        },
        timeout: 20000,
      });
      this.loading = false
      console.info(response)
      this.userData = response.data.memberInfo
      this.logined = true
      this.getHistory()
      this.getRedeemGift()
      this.getRedeemHistory()
      self.props.navigation.goBack()
    } catch (error) {
      this.loading = false;
      this.log(error.response);
      self.refs.toast.show(error.response.data.msg)
    }
  }

  async languageInit() {
    try {
      const value = await AsyncStorage.getItem('lang')
      if (value != null) {
        this.lang = value
        if (value == 'Tc') {
          I18n.locale = "zh_hk"
        } else if (value == 'En') {
          I18n.locale = "en";
        }
      } else {
        I18n.locale = "zh_hk"
      }
    } catch (e) {
      console.log(e)
    }
  }

  async searchItems(key, self) {
    this.loading = true
    var url = api.search;
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
          keyword: key,
        },
        timeout: 20000,
      });
      this.loading = false
      if (response.data.count > 0) {
        this.searchResult = response.data.data
      } else {
        this.searchResult = []
      }

      self.props.navigation.navigate('Search')
      this.log(response);
    } catch (error) {
      this.loading = false;
      this.log(error);
    }
  }

  async addOrRemoveFavourite(id) {
    var itemIndex = -1
    if (this.favouriteProducts.findIndex(e => e == id) > -1) {
      itemIndex = await this.products.findIndex(item => item.productId == id)
      if (itemIndex > -1) {
        this.favouriteProducts.splice(this.favouriteProducts.findIndex(favItem => favItem == id), 1);
        this.products[itemIndex].favourite = false
      }
    } else {
      itemIndex = await this.products.findIndex(item => item.productId == id)
      if (itemIndex > -1) {
        this.favouriteProducts.push(id);
        this.products[itemIndex].favourite = true
      }
    }
    const data = { fav: this.favouriteProducts }
    try {
      const saveItem = JSON.stringify(data)
      await AsyncStorage.setItem('favourite', saveItem)
    } catch (e) {
      console.log(e)
    }
  }

  async shoppingCartInit() {
    try {
      const jsonValue = await AsyncStorage.getItem('shoppingCart')
      if (jsonValue != null) {
        const data = JSON.parse(jsonValue)
        this.shoppingCart = data.cart
        console.log(this.shoppingCart)
      }
    } catch (e) {
      console.log(e)
    }
  }


  async addShoppingCart(id, qty, option, self) {
    console.info(id, qty)
    var itemIndex = -1
    if (this.shoppingCart.findIndex(e => e.id == id) > -1) {
      self.refs.toast.show('購物車已存在此產品')
    } else {
      var data = {
        id: id,
        qty: qty,
        option: option,
      }
      this.shoppingCart.push(data)
      const saveData = { cart: this.shoppingCart }
      try {
        const saveItem = JSON.stringify(saveData)
        await AsyncStorage.setItem('shoppingCart', saveItem)
      } catch (e) {
        console.info(e)
      }

      self.refs.toast.show('已加入購物車')
    }
  }

  async deleteShoppingCart(id, index, self) {
    var itemIndex = -1
    itemIndex = await this.shoppingCart.findIndex(e => e.id == id)
    if (itemIndex > -1) {

      this.shoppingCart.splice(itemIndex, 1);
      self.cartItems.splice(index, 1);
      try {
        const saveData = { cart: this.shoppingCart }
        const saveItem = JSON.stringify(saveData)
        await AsyncStorage.setItem('shoppingCart', saveItem)
      } catch (e) {
        console.info(e)
      }
    }
  }

  async changeQtyOnCart(id, index, qty, self) {
    console.info(id, index, qty)
    var itemIndex = -1
    itemIndex = await this.shoppingCart.findIndex(e => e.id == id)
    if (itemIndex > -1) {
      this.shoppingCart[itemIndex].qty = qty
      self.cartItems[index].qty = qty
      console.info(self.cartItems)
      try {
        const saveData = { cart: this.shoppingCart }
        const saveItem = JSON.stringify(saveData)
        await AsyncStorage.setItem('shoppingCart', saveItem)
      } catch (e) {
        console.info(e)
      }
    }
  }


  async changeQtyOnDetails(id, qty, self) {
    var itemIndex = -1
    itemIndex = await this.shoppingCart.findIndex(e => e.id == id)
    if (itemIndex > -1) {
      this.shoppingCart[itemIndex].qty = parseInt(qty)
      self.itemQtySelected = parseInt(qty)
      try {
        const saveData = { cart: this.shoppingCart }
        const saveItem = JSON.stringify(saveData)
        await AsyncStorage.setItem('shoppingCart', saveItem)
      } catch (e) {
        console.info(e)
      }
    } else {
      self.itemQtySelected = parseInt(qty)
    }
  }

  async changeOptionOnCart(id, index, option, self) {
    var itemIndex = -1
    itemIndex = await this.shoppingCart.findIndex(e => e.id == id)
    if (itemIndex > -1) {
      this.shoppingCart[itemIndex].option = option
      self.cartItems[index].option = option
      try {
        const saveData = { cart: this.shoppingCart }
        const saveItem = JSON.stringify(saveData)
        await AsyncStorage.setItem('shoppingCart', saveItem)
      } catch (e) {
        console.info(e)
      }
    } else {
      self.itemOption = option
    }
  }

  async changeOptionOnDetails(id, option, self) {
    var itemIndex = -1
    itemIndex = await this.shoppingCart.findIndex(e => e.id == id)
    if (itemIndex > -1) {
      this.shoppingCart[itemIndex].option = option
      self.itemOption = option
      try {
        const saveData = { cart: this.shoppingCart }
        const saveItem = JSON.stringify(saveData)
        await AsyncStorage.setItem('shoppingCart', saveItem)
      } catch (e) {
        console.info(e)
      }
    } else {
      self.itemOption = option
    }
  }

  async favouriteInit() {
    try {
      const jsonValue = await AsyncStorage.getItem('favourite')
      if (jsonValue != null) {
        const data = JSON.parse(jsonValue)
        this.favouriteProducts = data.fav
        console.log(this.favouriteProducts)
        Promise.all(this.favouriteProducts.map(async (item, index) => {
          const itemIndex = await this.products.findIndex(e => e.productId == item)
          if (itemIndex != -1) {
            this.products[itemIndex].favourite = true
            console.log(this.products[itemIndex].favourite)
          }
        }))
      }
    } catch (e) {
      console.log(e)
    }
  }

  log(message) {
    if (showLog) {
      console.log(message)
    }
  }
  setRouterState = state => {
    this.routerState = state;
    console.log(this.routerState)
  };

  changeText() {
    this.test = 'yo'
  }

  setRouterRef = ref => {
    this.routerRef = ref;
    console.log(this.routerRef)
  };

  async goToSubCatPage(catId, catName, self) {
    this.loading = true
    var url = api.subCategory;
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
          categoryId: catId,
        },
        timeout: 20000,
      });
      this.loading = false
      self.props.navigation.navigate('CategoryGrid', { subCategory: response.data, name: catName, catId: catId })
      this.log(response);
    } catch (error) {
      this.loading = false;
      this.log(error);
    }
  }

  async goToProductDetails(id, self) {
    this.loading = true
    var url = api.productDetails;
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
          productId: id,
        },
        timeout: 20000,
      });
      this.loading = false
      self.props.navigation.push('ProductsDetails', { data: response.data })
      this.log(response);
    } catch (error) {
      this.loading = false;
      this.log(error);
    }
  }

  async getProductsList(categoryId, type, limit) {
    this.products = []
    var url = api.products;
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: {
          lang: this.lang,
          categoryId: '',
          type: type,
          limit: limit == '0' ? '' : limit
        },
        timeout: 20000,
      });
      this.products = response.data
      await this.favouriteInit()
      await this.shoppingCartInit()
      this.splash = true
      this.log(response);
    } catch (error) {
      this.loading = false;
      this.log(error);
    }
  }

  async getCategory() {
    this.category = []
    var url = api.category;
    console.info(this.lang)
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: { lang: this.lang },
        timeout: 20000,
      });
      this.category = response.data
      this.log(response);
    } catch (error) {
      this.loading = false;
      this.log(error);
    }
  }

  async getBanner() {
    this.banner = [];
    var url = api.banner;
    try {
      const response = await axios.get(url, {
        headers: {
          'Content-Type': 'application/json',
        },
        params: { lang: this.lang },
        timeout: 20000,
      });
      this.banner = response.data
      console.info(response);
    } catch (error) {
      this.loading = false;
      this.log(error);
    }
  }
}


export default new Stores();
